@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -19,29 +25,29 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import annotations
-
 """Chained datastore."""
 
+from __future__ import annotations
+
 __all__ = ("ChainedDatastore",)
 
 import itertools
 import logging
 import time
 import warnings
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Set, Tuple, Union
+from collections.abc import Iterable, Mapping, Sequence
+from typing import TYPE_CHECKING, Any
 
-from lsst.daf.butler import (
-    Constraints,
-    DatasetRef,
+from lsst.daf.butler import DatasetRef, DatasetTypeNotSupportedError, FileDataset
+from lsst.daf.butler.datastore import (
     DatasetRefURIs,
-    DatasetTypeNotSupportedError,
     Datastore,
     DatastoreConfig,
-    DatastoreRecordData,
+    DatastoreOpaqueTable,
     DatastoreValidationError,
-    FileDataset,
 )
+from lsst.daf.butler.datastore.constraints import Constraints
+from lsst.daf.butler.datastore.record_data import DatastoreRecordData
 from lsst.resources import ResourcePath
 from lsst.utils import doImportType
 
@@ -62,7 +68,7 @@ class _IngestPrepData(Datastore.IngestPrepData):
         Pairs of `Datastore`, `IngestPrepData` for all child datastores.
     """
 
-    def __init__(self, children: List[Tuple[Datastore, Datastore.IngestPrepData, set[ResourcePath]]]):
+    def __init__(self, children: list[tuple[Datastore, Datastore.IngestPrepData, set[ResourcePath]]]):
         super().__init__(itertools.chain.from_iterable(data.refs.values() for _, data, _ in children))
         self.children = children
 
@@ -102,10 +108,10 @@ class ChainedDatastore(Datastore):
     containerKey = "datastores"
     """Key to specify where child datastores are configured."""
 
-    datastores: List[Datastore]
+    datastores: list[Datastore]
     """All the child datastores known to this datastore."""
 
-    datastoreConstraints: Sequence[Optional[Constraints]]
+    datastoreConstraints: Sequence[Constraints | None]
     """Constraints to be applied to each of the child datastores."""
 
     @classmethod
@@ -139,7 +145,6 @@ class ChainedDatastore(Datastore):
         will not be overridden by this method if ``overwrite`` is `False`.
         This allows explicit values set in external configs to be retained.
         """
-
         # Extract the part of the config we care about updating
         datastoreConfig = DatastoreConfig(config, mergeDefaults=False)
 
@@ -153,14 +158,14 @@ class ChainedDatastore(Datastore):
 
         containerKey = cls.containerKey
         for idx, (child, fullChild) in enumerate(
-            zip(datastoreConfig[containerKey], fullDatastoreConfig[containerKey])
+            zip(datastoreConfig[containerKey], fullDatastoreConfig[containerKey], strict=True)
         ):
             childConfig = DatastoreConfig(child, mergeDefaults=False)
             fullChildConfig = DatastoreConfig(fullChild, mergeDefaults=False)
             datastoreClass = doImportType(fullChildConfig["cls"])
             if not issubclass(datastoreClass, Datastore):
                 raise TypeError(f"Imported child class {fullChildConfig['cls']} is not a Datastore")
-            newroot = "{}/{}_{}".format(root, datastoreClass.__qualname__, idx)
+            newroot = f"{root}/{datastoreClass.__qualname__}_{idx}"
             datastoreClass.setConfigRoot(newroot, childConfig, fullChildConfig, overwrite=overwrite)
 
             # Reattach to parent
@@ -178,7 +183,7 @@ class ChainedDatastore(Datastore):
 
     def __init__(
         self,
-        config: Union[Config, str],
+        config: Config | ResourcePathExpression,
         bridgeManager: DatastoreRegistryBridgeManager,
         butlerRoot: str | None = None,
     ):
@@ -201,18 +206,13 @@ class ChainedDatastore(Datastore):
             self._names = [d.name for d in self.datastores]
             childNames = ",".join(self.names)
         else:
-            childNames = "(empty@{})".format(time.time())
+            childNames = f"(empty@{time.time()})"
             self._names = [childNames]
-        self.name = "{}[{}]".format(type(self).__qualname__, childNames)
+        self.name = f"{type(self).__qualname__}[{childNames}]"
 
         # We declare we are ephemeral if all our child datastores declare
         # they are ephemeral
-        isEphemeral = True
-        for d in self.datastores:
-            if not d.isEphemeral:
-                isEphemeral = False
-                break
-        self.isEphemeral = isEphemeral
+        self.isEphemeral = all(d.isEphemeral for d in self.datastores)
 
         # per-datastore override constraints
         if "datastore_constraints" in self.config:
@@ -235,9 +235,17 @@ class ChainedDatastore(Datastore):
         log.debug("Created %s (%s)", self.name, ("ephemeral" if self.isEphemeral else "permanent"))
 
     @property
-    def names(self) -> Tuple[str, ...]:
+    def names(self) -> tuple[str, ...]:
         return tuple(self._names)
 
+    @property
+    def roots(self) -> dict[str, ResourcePath | None]:
+        # Docstring inherited.
+        roots = {}
+        for datastore in self.datastores:
+            roots.update(datastore.roots)
+        return roots
+
     def __str__(self) -> str:
         chainName = ", ".join(str(ds) for ds in self.datastores)
         return chainName
@@ -276,8 +284,8 @@ class ChainedDatastore(Datastore):
         return refs_known
 
     def mexists(
-        self, refs: Iterable[DatasetRef], artifact_existence: Optional[Dict[ResourcePath, bool]] = None
-    ) -> Dict[DatasetRef, bool]:
+        self, refs: Iterable[DatasetRef], artifact_existence: dict[ResourcePath, bool] | None = None
+    ) -> dict[DatasetRef, bool]:
         """Check the existence of multiple datasets at once.
 
         Parameters
@@ -295,7 +303,7 @@ class ChainedDatastore(Datastore):
             Mapping from dataset to boolean indicating existence in any
             of the child datastores.
         """
-        dataset_existence: Dict[DatasetRef, bool] = {}
+        dataset_existence: dict[DatasetRef, bool] = {}
         for datastore in self.datastores:
             dataset_existence.update(datastore.mexists(refs, artifact_existence=artifact_existence))
 
@@ -327,8 +335,8 @@ class ChainedDatastore(Datastore):
     def get(
         self,
         ref: DatasetRef,
-        parameters: Optional[Mapping[str, Any]] = None,
-        storageClass: Optional[Union[StorageClass, str]] = None,
+        parameters: Mapping[str, Any] | None = None,
+        storageClass: StorageClass | str | None = None,
     ) -> Any:
         """Load an InMemoryDataset from the store.
 
@@ -363,7 +371,6 @@ class ChainedDatastore(Datastore):
         ValueError
             Formatter failed to process the dataset.
         """
-
         for datastore in self.datastores:
             try:
                 inMemoryObject = datastore.get(ref, parameters, storageClass=storageClass)
@@ -372,7 +379,7 @@ class ChainedDatastore(Datastore):
             except FileNotFoundError:
                 pass
 
-        raise FileNotFoundError("Dataset {} could not be found in any of the datastores".format(ref))
+        raise FileNotFoundError(f"Dataset {ref} could not be found in any of the datastores")
 
     def put(self, inMemoryDataset: Any, ref: DatasetRef) -> None:
         """Write a InMemoryDataset with a given `DatasetRef` to each
@@ -410,8 +417,10 @@ class ChainedDatastore(Datastore):
         nsuccess = 0
         npermanent = 0
         nephemeral = 0
-        for datastore, constraints in zip(self.datastores, self.datastoreConstraints):
-            if constraints is not None and not constraints.isAcceptable(ref):
+        for datastore, constraints in zip(self.datastores, self.datastoreConstraints, strict=True):
+            if (
+                constraints is not None and not constraints.isAcceptable(ref)
+            ) or not datastore.constraints.isAcceptable(ref):
                 log.debug("Datastore %s skipping put via configuration for ref %s", datastore.name, ref)
                 continue
 
@@ -436,7 +445,54 @@ class ChainedDatastore(Datastore):
         if self._transaction is not None:
             self._transaction.registerUndo("put", self.remove, ref)
 
-    def _overrideTransferMode(self, *datasets: Any, transfer: Optional[str] = None) -> Optional[str]:
+    def put_new(self, in_memory_dataset: Any, ref: DatasetRef) -> Mapping[str, DatasetRef]:
+        # Docstring inherited from base class.
+        log.debug("Put %s", ref)
+
+        # Confirm that we can accept this dataset
+        if not self.constraints.isAcceptable(ref):
+            # Raise rather than use boolean return value.
+            raise DatasetTypeNotSupportedError(
+                f"Dataset {ref} has been rejected by this datastore via configuration."
+            )
+
+        isPermanent = False
+        nsuccess = 0
+        npermanent = 0
+        nephemeral = 0
+        stored_refs: dict[str, DatasetRef] = {}
+        for datastore, constraints in zip(self.datastores, self.datastoreConstraints, strict=True):
+            if (
+                constraints is not None and not constraints.isAcceptable(ref)
+            ) or not datastore.constraints.isAcceptable(ref):
+                log.debug("Datastore %s skipping put via configuration for ref %s", datastore.name, ref)
+                continue
+
+            if datastore.isEphemeral:
+                nephemeral += 1
+            else:
+                npermanent += 1
+            try:
+                stored_ref_map = datastore.put_new(in_memory_dataset, ref)
+                stored_refs.update(stored_ref_map)
+                nsuccess += 1
+                if not datastore.isEphemeral:
+                    isPermanent = True
+            except DatasetTypeNotSupportedError:
+                pass
+
+        if nsuccess == 0:
+            raise DatasetTypeNotSupportedError(f"None of the chained datastores supported ref {ref}")
+
+        if not isPermanent and npermanent > 0:
+            warnings.warn(f"Put of {ref} only succeeded in ephemeral databases", stacklevel=2)
+
+        if self._transaction is not None:
+            self._transaction.registerUndo("put", self.remove, ref)
+
+        return stored_refs
+
+    def _overrideTransferMode(self, *datasets: Any, transfer: str | None = None) -> str | None:
         # Docstring inherited from base class.
         if transfer != "auto":
             return transfer
@@ -457,7 +513,7 @@ class ChainedDatastore(Datastore):
             f" from 'auto' in each child datastore (wanted {transfers})"
         )
 
-    def _prepIngest(self, *datasets: FileDataset, transfer: Optional[str] = None) -> _IngestPrepData:
+    def _prepIngest(self, *datasets: FileDataset, transfer: str | None = None) -> _IngestPrepData:
         # Docstring inherited from Datastore._prepIngest.
         if transfer is None:
             raise NotImplementedError("ChainedDatastore does not support transfer=None.")
@@ -476,7 +532,7 @@ class ChainedDatastore(Datastore):
 
         # Filter down to just datasets the chained datastore's own
         # configuration accepts.
-        okForParent: List[FileDataset] = [
+        okForParent: list[FileDataset] = [
             dataset
             for dataset in datasets
             if isDatasetAcceptable(dataset, name=self.name, constraints=self.constraints)
@@ -484,12 +540,12 @@ class ChainedDatastore(Datastore):
 
         # Iterate over nested datastores and call _prepIngest on each.
         # Save the results to a list:
-        children: List[Tuple[Datastore, Datastore.IngestPrepData, set[ResourcePath]]] = []
+        children: list[tuple[Datastore, Datastore.IngestPrepData, set[ResourcePath]]] = []
         # ...and remember whether all of the failures are due to
         # NotImplementedError being raised.
         allFailuresAreNotImplementedError = True
-        for datastore, constraints in zip(self.datastores, self.datastoreConstraints):
-            okForChild: List[FileDataset]
+        for datastore, constraints in zip(self.datastores, self.datastoreConstraints, strict=True):
+            okForChild: list[FileDataset]
             if constraints is not None:
                 okForChild = [
                     dataset
@@ -526,7 +582,7 @@ class ChainedDatastore(Datastore):
         self,
         prepData: _IngestPrepData,
         *,
-        transfer: Optional[str] = None,
+        transfer: str | None = None,
         record_validation_info: bool = True,
     ) -> None:
         # Docstring inherited from Datastore._finishIngest.
@@ -556,10 +612,10 @@ class ChainedDatastore(Datastore):
         refs: Iterable[DatasetRef],
         predict: bool = False,
         allow_missing: bool = False,
-    ) -> Dict[DatasetRef, DatasetRefURIs]:
+    ) -> dict[DatasetRef, DatasetRefURIs]:
         # Docstring inherited
 
-        uris: Dict[DatasetRef, DatasetRefURIs] = {}
+        uris: dict[DatasetRef, DatasetRefURIs] = {}
         missing_refs = set(refs)
 
         # If predict is True we don't want to predict a dataset in the first
@@ -570,7 +626,11 @@ class ChainedDatastore(Datastore):
             if not missing_refs:
                 break
             for datastore in self.datastores:
-                got_uris = datastore.getManyURIs(missing_refs, p, allow_missing=True)
+                try:
+                    got_uris = datastore.getManyURIs(missing_refs, p, allow_missing=True)
+                except NotImplementedError:
+                    # some datastores may not implement generating URIs
+                    continue
                 missing_refs -= got_uris.keys()
                 uris.update(got_uris)
                 if not missing_refs:
@@ -589,8 +649,8 @@ class ChainedDatastore(Datastore):
         ref : `DatasetRef`
             Reference to the required dataset.
         predict : `bool`, optional
-            If the datastore does not know about the dataset, should it
-            return a predicted URI or not?
+            If the datastore does not know about the dataset, controls whether
+            it should return a predicted URI or not.
 
         Returns
         -------
@@ -609,9 +669,9 @@ class ChainedDatastore(Datastore):
         be returned.
         """
         log.debug("Requesting URIs for %s", ref)
-        predictedUri: Optional[DatasetRefURIs] = None
-        predictedEphemeralUri: Optional[DatasetRefURIs] = None
-        firstEphemeralUri: Optional[DatasetRefURIs] = None
+        predictedUri: DatasetRefURIs | None = None
+        predictedEphemeralUri: DatasetRefURIs | None = None
+        firstEphemeralUri: DatasetRefURIs | None = None
         for datastore in self.datastores:
             if datastore.exists(ref):
                 if not datastore.isEphemeral:
@@ -638,7 +698,7 @@ class ChainedDatastore(Datastore):
             log.debug("Retrieved predicted ephemeral URI: %s", predictedEphemeralUri)
             return predictedEphemeralUri
 
-        raise FileNotFoundError("Dataset {} not in any datastore".format(ref))
+        raise FileNotFoundError(f"Dataset {ref} not in any datastore")
 
     def getURI(self, ref: DatasetRef, predict: bool = False) -> ResourcePath:
         """URI to the Dataset.
@@ -695,7 +755,7 @@ class ChainedDatastore(Datastore):
         transfer: str = "auto",
         preserve_path: bool = True,
         overwrite: bool = False,
-    ) -> List[ResourcePath]:
+    ) -> list[ResourcePath]:
         """Retrieve the file artifacts associated with the supplied refs.
 
         Parameters
@@ -737,7 +797,7 @@ class ChainedDatastore(Datastore):
         # early if some of the refs are missing, or whether files should be
         # transferred until a problem is hit. Prefer to complain up front.
         # Use the datastore integer as primary key.
-        grouped_by_datastore: Dict[int, Set[DatasetRef]] = {}
+        grouped_by_datastore: dict[int, set[DatasetRef]] = {}
 
         for number, datastore in enumerate(self.datastores):
             if datastore.isEphemeral:
@@ -745,7 +805,11 @@ class ChainedDatastore(Datastore):
                 # caching datastore since using an on-disk local
                 # cache is exactly what we should be doing.
                 continue
-            datastore_refs = {ref for ref in pending if datastore.exists(ref)}
+            try:
+                datastore_refs = {ref for ref in pending if datastore.exists(ref)}
+            except NotImplementedError:
+                # Some datastores may not support retrieving artifacts
+                continue
 
             if datastore_refs:
                 grouped_by_datastore[number] = datastore_refs
@@ -758,7 +822,7 @@ class ChainedDatastore(Datastore):
             raise RuntimeError(f"Some datasets were not found in any datastores: {pending}")
 
         # Now do the transfer.
-        targets: List[ResourcePath] = []
+        targets: list[ResourcePath] = []
         for number, datastore_refs in grouped_by_datastore.items():
             targets.extend(
                 self.datastores[number].retrieveArtifacts(
@@ -797,7 +861,7 @@ class ChainedDatastore(Datastore):
         for datastore in tuple(self.datastores):
             datastore.forget(refs)
 
-    def trash(self, ref: Union[DatasetRef, Iterable[DatasetRef]], ignore_errors: bool = True) -> None:
+    def trash(self, ref: DatasetRef | Iterable[DatasetRef], ignore_errors: bool = True) -> None:
         if isinstance(ref, DatasetRef):
             ref_label = str(ref)
         else:
@@ -846,7 +910,7 @@ class ChainedDatastore(Datastore):
         self.put(inMemoryDataset, ref)
 
     def validateConfiguration(
-        self, entities: Iterable[Union[DatasetRef, DatasetType, StorageClass]], logFailures: bool = False
+        self, entities: Iterable[DatasetRef | DatasetType | StorageClass], logFailures: bool = False
     ) -> None:
         """Validate some of the configuration for this datastore.
 
@@ -869,7 +933,6 @@ class ChainedDatastore(Datastore):
         -----
         This method checks each datastore in turn.
         """
-
         # Need to catch each of the datastore outputs and ensure that
         # all are tested.
         failures = []
@@ -885,7 +948,7 @@ class ChainedDatastore(Datastore):
             msg = ";\n".join(failures)
             raise DatastoreValidationError(msg)
 
-    def validateKey(self, lookupKey: LookupKey, entity: Union[DatasetRef, DatasetType, StorageClass]) -> None:
+    def validateKey(self, lookupKey: LookupKey, entity: DatasetRef | DatasetType | StorageClass) -> None:
         # Docstring is inherited from base class
         failures = []
         for datastore in self.datastores:
@@ -898,7 +961,7 @@ class ChainedDatastore(Datastore):
             msg = ";\n".join(failures)
             raise DatastoreValidationError(msg)
 
-    def getLookupKeys(self) -> Set[LookupKey]:
+    def getLookupKeys(self) -> set[LookupKey]:
         # Docstring is inherited from base class
         keys = set()
         for datastore in self.datastores:
@@ -913,8 +976,8 @@ class ChainedDatastore(Datastore):
 
     def needs_expanded_data_ids(
         self,
-        transfer: Optional[str],
-        entity: Optional[Union[DatasetRef, DatasetType, StorageClass]] = None,
+        transfer: str | None,
+        entity: DatasetRef | DatasetType | StorageClass | None = None,
     ) -> bool:
         # Docstring inherited.
         # We can't safely use `self.datastoreConstraints` with `entity` to
@@ -935,7 +998,7 @@ class ChainedDatastore(Datastore):
     def export_records(self, refs: Iterable[DatasetIdRef]) -> Mapping[str, DatastoreRecordData]:
         # Docstring inherited from the base class.
 
-        all_records: Dict[str, DatastoreRecordData] = {}
+        all_records: dict[str, DatastoreRecordData] = {}
 
         # Merge all sub-datastore records into one structure
         for datastore in self.datastores:
@@ -952,8 +1015,8 @@ class ChainedDatastore(Datastore):
         self,
         refs: Iterable[DatasetRef],
         *,
-        directory: Optional[ResourcePathExpression] = None,
-        transfer: Optional[str] = "auto",
+        directory: ResourcePathExpression | None = None,
+        transfer: str | None = "auto",
     ) -> Iterable[FileDataset]:
         # Docstring inherited from Datastore.export.
         if transfer == "auto" and directory is None:
@@ -1008,7 +1071,7 @@ class ChainedDatastore(Datastore):
                 # Try the next datastore.
                 continue
 
-            for ref, export in zip(filtered, this_export):
+            for ref, export in zip(filtered, this_export, strict=True):
                 # Get the position and also delete it from the list.
                 exported[ref_positions.pop(ref)] = export
 
@@ -1024,7 +1087,7 @@ class ChainedDatastore(Datastore):
         source_datastore: Datastore,
         refs: Iterable[DatasetRef],
         transfer: str = "auto",
-        artifact_existence: Optional[Dict[ResourcePath, bool]] = None,
+        artifact_existence: dict[ResourcePath, bool] | None = None,
     ) -> tuple[set[DatasetRef], set[DatasetRef]]:
         # Docstring inherited
         # mypy does not understand "type(self) is not type(source)"
@@ -1034,7 +1097,7 @@ class ChainedDatastore(Datastore):
         else:
             # The source datastore is different, forward everything to the
             # child datastores.
-            source_datastores = tuple([source_datastore])
+            source_datastores = (source_datastore,)
 
         # Need to know the set of all possible refs that could be transferred.
         remaining_refs = set(refs)
@@ -1048,7 +1111,7 @@ class ChainedDatastore(Datastore):
             # ask the receiving datastore to copy it when it doesn't exist
             # so we have to filter again based on what the source datastore
             # understands.
-            known_to_source = source_child.knows_these([ref for ref in refs])
+            known_to_source = source_child.knows_these(list(refs))
 
             # Need to know that there is a possibility that some of these
             # datasets exist but are unknown to the source datastore if
@@ -1081,7 +1144,7 @@ class ChainedDatastore(Datastore):
                 # Already transferred all datasets known to this datastore.
                 continue
 
-            for datastore, constraints in zip(self.datastores, self.datastoreConstraints):
+            for datastore, constraints in zip(self.datastores, self.datastoreConstraints, strict=True):
                 if constraints is not None:
                     filtered_refs = []
                     for ref in these_refs:
@@ -1090,7 +1153,7 @@ class ChainedDatastore(Datastore):
                         else:
                             log.debug("Rejecting ref by constraints: %s", ref)
                 else:
-                    filtered_refs = [ref for ref in these_refs]
+                    filtered_refs = list(these_refs)
                 try:
                     accepted, _ = datastore.transfer_from(
                         source_child, filtered_refs, transfer, artifact_existence
@@ -1115,3 +1178,10 @@ class ChainedDatastore(Datastore):
             raise TypeError(f"None of the child datastores could accept transfers from {source_datastore!r}")
 
         return all_accepted, remaining_refs
+
+    def get_opaque_table_definitions(self) -> Mapping[str, DatastoreOpaqueTable]:
+        # Docstring inherited from the base class.
+        tables: dict[str, DatastoreOpaqueTable] = {}
+        for datastore in self.datastores:
+            tables.update(datastore.get_opaque_table_definitions())
+        return tables
