@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -20,6 +26,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from __future__ import annotations
 
+from ... import ddl
+
 __all__ = ("MonolithicDatastoreRegistryBridgeManager", "MonolithicDatastoreRegistryBridge")
 
 import copy
@@ -30,7 +38,8 @@ from typing import TYPE_CHECKING, cast
 
 import sqlalchemy
 
-from ...core import NamedValueSet, StoredDatastoreItemInfo, ddl
+from ..._named import NamedValueSet
+from ...datastore.stored_file_info import StoredDatastoreItemInfo
 from ..interfaces import (
     DatasetIdRef,
     DatastoreRegistryBridge,
@@ -43,8 +52,8 @@ from ..opaque import ByNameOpaqueTableStorage
 from .ephemeral import EphemeralDatastoreRegistryBridge
 
 if TYPE_CHECKING:
-    from ...core import DimensionUniverse
-    from ...core.datastore import DatastoreTransaction
+    from ...datastore import DatastoreTransaction
+    from ...dimensions import DimensionUniverse
     from ..interfaces import (
         Database,
         DatasetRecordStorageManager,
@@ -70,8 +79,6 @@ def _makeTableSpecs(datasets: type[DatasetRecordStorageManager]) -> _TablesTuple
 
     Parameters
     ----------
-    universe : `DimensionUniverse`
-        All dimensions known to the `Registry`.
     datasets : subclass of `DatasetRecordStorageManager`
         Manager class for datasets; used only to create foreign key fields.
 
@@ -311,6 +318,8 @@ class MonolithicDatastoreRegistryBridgeManager(DatastoreRegistryBridgeManager):
         All dimensions know to the `Registry`.
     datasetIdColumnType : `type`
         Type for dataset ID column.
+    registry_schema_version : `VersionTuple` or `None`, optional
+        The version of the registry schema.
     """
 
     def __init__(
