@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -20,24 +26,26 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from __future__ import annotations
 
+from ... import ddl
+
 __all__ = ()
 
 import itertools
 from abc import abstractmethod
 from collections import namedtuple
 from collections.abc import Iterable, Iterator, Set
-from typing import TYPE_CHECKING, Any, Generic, TypeVar, cast
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 import sqlalchemy
-from lsst.utils.ellipsis import Ellipsis
 
-from ...core import DimensionUniverse, Timespan, TimespanDatabaseRepresentation, ddl
-from .._collectionType import CollectionType
+from ...timespan_database_representation import TimespanDatabaseRepresentation
+from .._collection_type import CollectionType
 from .._exceptions import MissingCollectionError
 from ..interfaces import ChainedCollectionRecord, CollectionManager, CollectionRecord, RunRecord, VersionTuple
 from ..wildcards import CollectionWildcard
 
 if TYPE_CHECKING:
+    from .._caching_context import CachingContext
     from ..interfaces import Database, DimensionRecordStorageManager
 
 
@@ -81,14 +89,13 @@ def makeRunTableSpec(
     ----------
     collectionIdName : `str`
         Name of the column in collections table that identifies it (PK).
-    collectionIdType
+    collectionIdType : `type`
         Type of the PK column in the collections table, one of the
         `sqlalchemy` types.
     TimespanReprClass : `type` [ `TimespanDatabaseRepresentation` ]
         Subclass of `TimespanDatabaseRepresentation` that encapsulates how
         timespans are stored in this database.
 
-
     Returns
     -------
     spec : `ddl.TableSpec`
@@ -121,7 +128,7 @@ def makeCollectionChainTableSpec(collectionIdName: str, collectionIdType: type)
     ----------
     collectionIdName : `str`
         Name of the column in collections table that identifies it (PK).
-    collectionIdType
+    collectionIdType : `type`
         Type of the PK column in the collections table, one of the
         `sqlalchemy` types.
 
@@ -149,150 +156,10 @@ def makeCollectionChainTableSpec(collectionIdName: str, collectionIdType: type)
     )
 
 
-class DefaultRunRecord(RunRecord):
-    """Default `RunRecord` implementation.
-
-    This method assumes the same run table definition as produced by
-    `makeRunTableSpec` method. The only non-fixed name in the schema
-    is the PK column name, this needs to be passed in a constructor.
-
-    Parameters
-    ----------
-    db : `Database`
-        Registry database.
-    key
-        Unique collection ID, can be the same as ``name`` if ``name`` is used
-        for identification. Usually this is an integer or string, but can be
-        other database-specific type.
-    name : `str`
-        Run collection name.
-    table : `sqlalchemy.schema.Table`
-        Table for run records.
-    idColumnName : `str`
-        Name of the identifying column in run table.
-    host : `str`, optional
-        Name of the host where run was produced.
-    timespan : `Timespan`, optional
-        Timespan for this run.
-    """
-
-    def __init__(
-        self,
-        db: Database,
-        key: Any,
-        name: str,
-        *,
-        table: sqlalchemy.schema.Table,
-        idColumnName: str,
-        host: str | None = None,
-        timespan: Timespan | None = None,
-    ):
-        super().__init__(key=key, name=name, type=CollectionType.RUN)
-        self._db = db
-        self._table = table
-        self._host = host
-        if timespan is None:
-            timespan = Timespan(begin=None, end=None)
-        self._timespan = timespan
-        self._idName = idColumnName
-
-    def update(self, host: str | None = None, timespan: Timespan | None = None) -> None:
-        # Docstring inherited from RunRecord.
-        if timespan is None:
-            timespan = Timespan(begin=None, end=None)
-        row = {
-            self._idName: self.key,
-            "host": host,
-        }
-        self._db.getTimespanRepresentation().update(timespan, result=row)
-        count = self._db.update(self._table, {self._idName: self.key}, row)
-        if count != 1:
-            raise RuntimeError(f"Run update affected {count} records; expected exactly one.")
-        self._host = host
-        self._timespan = timespan
-
-    @property
-    def host(self) -> str | None:
-        # Docstring inherited from RunRecord.
-        return self._host
-
-    @property
-    def timespan(self) -> Timespan:
-        # Docstring inherited from RunRecord.
-        return self._timespan
-
-
-class DefaultChainedCollectionRecord(ChainedCollectionRecord):
-    """Default `ChainedCollectionRecord` implementation.
-
-    This method assumes the same chain table definition as produced by
-    `makeCollectionChainTableSpec` method. All column names in the table are
-    fixed and hard-coded in the methods.
-
-    Parameters
-    ----------
-    db : `Database`
-        Registry database.
-    key
-        Unique collection ID, can be the same as ``name`` if ``name`` is used
-        for identification. Usually this is an integer or string, but can be
-        other database-specific type.
-    name : `str`
-        Collection name.
-    table : `sqlalchemy.schema.Table`
-        Table for chain relationship records.
-    universe : `DimensionUniverse`
-        Object managing all known dimensions.
-    """
-
-    def __init__(
-        self,
-        db: Database,
-        key: Any,
-        name: str,
-        *,
-        table: sqlalchemy.schema.Table,
-        universe: DimensionUniverse,
-    ):
-        super().__init__(key=key, name=name, universe=universe)
-        self._db = db
-        self._table = table
-        self._universe = universe
-
-    def _update(self, manager: CollectionManager, children: tuple[str, ...]) -> None:
-        # Docstring inherited from ChainedCollectionRecord.
-        rows = []
-        position = itertools.count()
-        for child in manager.resolve_wildcard(CollectionWildcard.from_names(children), flatten_chains=False):
-            rows.append(
-                {
-                    "parent": self.key,
-                    "child": child.key,
-                    "position": next(position),
-                }
-            )
-        with self._db.transaction():
-            self._db.delete(self._table, ["parent"], {"parent": self.key})
-            self._db.insert(self._table, *rows)
-
-    def _load(self, manager: CollectionManager) -> tuple[str, ...]:
-        # Docstring inherited from ChainedCollectionRecord.
-        sql = (
-            sqlalchemy.sql.select(
-                self._table.columns.child,
-            )
-            .select_from(self._table)
-            .where(self._table.columns.parent == self.key)
-            .order_by(self._table.columns.position)
-        )
-        with self._db.query(sql) as sql_result:
-            return tuple(manager[row[self._table.columns.child]].name for row in sql_result.mappings())
-
-
 K = TypeVar("K")
 
 
-class DefaultCollectionManager(Generic[K], CollectionManager):
+class DefaultCollectionManager(CollectionManager[K]):
     """Default `CollectionManager` implementation.
 
     This implementation uses record classes defined in this module and is
@@ -308,6 +175,10 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
         Name of the column in collections table that identifies it (PK).
     dimensions : `DimensionRecordStorageManager`
         Manager object for the dimensions in this `Registry`.
+    caching_context : `CachingContext`
+        Caching context to use.
+    registry_schema_version : `VersionTuple` or `None`, optional
+        The version of the registry schema.
 
     Notes
     -----
@@ -323,72 +194,34 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
         collectionIdName: str,
         *,
         dimensions: DimensionRecordStorageManager,
+        caching_context: CachingContext,
         registry_schema_version: VersionTuple | None = None,
     ):
         super().__init__(registry_schema_version=registry_schema_version)
         self._db = db
         self._tables = tables
         self._collectionIdName = collectionIdName
-        self._records: dict[K, CollectionRecord] = {}  # indexed by record ID
         self._dimensions = dimensions
+        self._caching_context = caching_context
 
     def refresh(self) -> None:
         # Docstring inherited from CollectionManager.
-        sql = sqlalchemy.sql.select(
-            *(list(self._tables.collection.columns) + list(self._tables.run.columns))
-        ).select_from(self._tables.collection.join(self._tables.run, isouter=True))
-        # Put found records into a temporary instead of updating self._records
-        # in place, for exception safety.
-        records = []
-        chains = []
-        TimespanReprClass = self._db.getTimespanRepresentation()
-        with self._db.query(sql) as sql_result:
-            sql_rows = sql_result.mappings().fetchall()
-        for row in sql_rows:
-            collection_id = row[self._tables.collection.columns[self._collectionIdName]]
-            name = row[self._tables.collection.columns.name]
-            type = CollectionType(row["type"])
-            record: CollectionRecord
-            if type is CollectionType.RUN:
-                record = DefaultRunRecord(
-                    key=collection_id,
-                    name=name,
-                    db=self._db,
-                    table=self._tables.run,
-                    idColumnName=self._collectionIdName,
-                    host=row[self._tables.run.columns.host],
-                    timespan=TimespanReprClass.extract(row),
-                )
-            elif type is CollectionType.CHAINED:
-                record = DefaultChainedCollectionRecord(
-                    db=self._db,
-                    key=collection_id,
-                    table=self._tables.collection_chain,
-                    name=name,
-                    universe=self._dimensions.universe,
-                )
-                chains.append(record)
-            else:
-                record = CollectionRecord(key=collection_id, name=name, type=type)
-            records.append(record)
-        self._setRecordCache(records)
-        for chain in chains:
-            try:
-                chain.refresh(self)
-            except MissingCollectionError:
-                # This indicates a race condition in which some other client
-                # created a new collection and added it as a child of this
-                # (pre-existing) chain between the time we fetched all
-                # collections and the time we queried for parent-child
-                # relationships.
-                # Because that's some other unrelated client, we shouldn't care
-                # about that parent collection anyway, so we just drop it on
-                # the floor (a manual refresh can be used to get it back).
-                self._removeCachedRecord(chain)
+        if self._caching_context.collection_records is not None:
+            self._caching_context.collection_records.clear()
+
+    def _fetch_all(self) -> list[CollectionRecord[K]]:
+        """Retrieve all records into cache if not done so yet."""
+        if self._caching_context.collection_records is not None:
+            if self._caching_context.collection_records.full:
+                return list(self._caching_context.collection_records.records())
+        records = self._fetch_by_key(None)
+        if self._caching_context.collection_records is not None:
+            self._caching_context.collection_records.set(records, full=True)
+        return records
 
     def register(
         self, name: str, type: CollectionType, doc: str | None = None
-    ) -> tuple[CollectionRecord, bool]:
+    ) -> tuple[CollectionRecord[K], bool]:
         # Docstring inherited from CollectionManager.
         registered = False
         record = self._getByName(name)
@@ -403,7 +236,7 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
             assert isinstance(inserted_or_updated, bool)
             registered = inserted_or_updated
             assert row is not None
-            collection_id = row[self._collectionIdName]
+            collection_id = cast(K, row[self._collectionIdName])
             if type is CollectionType.RUN:
                 TimespanReprClass = self._db.getTimespanRepresentation()
                 row, _ = self._db.sync(
@@ -412,25 +245,20 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
                     returning=("host",) + TimespanReprClass.getFieldNames(),
                 )
                 assert row is not None
-                record = DefaultRunRecord(
-                    db=self._db,
+                record = RunRecord[K](
                     key=collection_id,
                     name=name,
-                    table=self._tables.run,
-                    idColumnName=self._collectionIdName,
                     host=row["host"],
                     timespan=TimespanReprClass.extract(row),
                 )
             elif type is CollectionType.CHAINED:
-                record = DefaultChainedCollectionRecord(
-                    db=self._db,
+                record = ChainedCollectionRecord[K](
                     key=collection_id,
                     name=name,
-                    table=self._tables.collection_chain,
-                    universe=self._dimensions.universe,
+                    children=[],
                 )
             else:
-                record = CollectionRecord(key=collection_id, name=name, type=type)
+                record = CollectionRecord[K](key=collection_id, name=name, type=type)
             self._addCachedRecord(record)
         return record, registered
 
@@ -445,19 +273,48 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
         )
         self._removeCachedRecord(record)
 
-    def find(self, name: str) -> CollectionRecord:
+    def find(self, name: str) -> CollectionRecord[K]:
         # Docstring inherited from CollectionManager.
         result = self._getByName(name)
         if result is None:
             raise MissingCollectionError(f"No collection with name '{name}' found.")
         return result
 
-    def __getitem__(self, key: Any) -> CollectionRecord:
+    def _find_many(self, names: Iterable[str]) -> list[CollectionRecord[K]]:
+        """Return multiple records given their names."""
+        names = list(names)
+        # To protect against potential races in cache updates.
+        records: dict[str, CollectionRecord | None] = {}
+        if self._caching_context.collection_records is not None:
+            for name in names:
+                records[name] = self._caching_context.collection_records.get_by_name(name)
+            fetch_names = [name for name, record in records.items() if record is None]
+        else:
+            fetch_names = list(names)
+            records = {name: None for name in fetch_names}
+        if fetch_names:
+            for record in self._fetch_by_name(fetch_names):
+                records[record.name] = record
+                self._addCachedRecord(record)
+        missing_names = [name for name, record in records.items() if record is None]
+        if len(missing_names) == 1:
+            raise MissingCollectionError(f"No collection with name '{missing_names[0]}' found.")
+        elif len(missing_names) > 1:
+            raise MissingCollectionError(f"No collections with names '{' '.join(missing_names)}' found.")
+        return [cast(CollectionRecord[K], records[name]) for name in names]
+
+    def __getitem__(self, key: Any) -> CollectionRecord[K]:
         # Docstring inherited from CollectionManager.
-        try:
-            return self._records[key]
-        except KeyError as err:
-            raise MissingCollectionError(f"Collection with key '{key}' not found.") from err
+        if self._caching_context.collection_records is not None:
+            if (record := self._caching_context.collection_records.get_by_key(key)) is not None:
+                return record
+        if records := self._fetch_by_key([key]):
+            record = records[0]
+            if self._caching_context.collection_records is not None:
+                self._caching_context.collection_records.add(record)
+            return record
+        else:
+            raise MissingCollectionError(f"Collection with key '{key}' not found.")
 
     def resolve_wildcard(
         self,
@@ -467,13 +324,13 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
         done: set[str] | None = None,
         flatten_chains: bool = True,
         include_chains: bool | None = None,
-    ) -> list[CollectionRecord]:
+    ) -> list[CollectionRecord[K]]:
         # Docstring inherited
         if done is None:
             done = set()
         include_chains = include_chains if include_chains is not None else not flatten_chains
 
-        def resolve_nested(record: CollectionRecord, done: set[str]) -> Iterator[CollectionRecord]:
+        def resolve_nested(record: CollectionRecord, done: set[str]) -> Iterator[CollectionRecord[K]]:
             if record.name in done:
                 return
             if record.type in collection_types:
@@ -482,28 +339,29 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
                     yield record
             if flatten_chains and record.type is CollectionType.CHAINED:
                 done.add(record.name)
-                for name in cast(ChainedCollectionRecord, record).children:
+                for child in self._find_many(cast(ChainedCollectionRecord[K], record).children):
                     # flake8 can't tell that we only delete this closure when
                     # we're totally done with it.
-                    yield from resolve_nested(self.find(name), done)  # noqa: F821
+                    yield from resolve_nested(child, done)  # noqa: F821
 
-        result: list[CollectionRecord] = []
+        result: list[CollectionRecord[K]] = []
 
-        if wildcard.patterns is Ellipsis:
-            for record in self._records.values():
+        if wildcard.patterns is ...:
+            for record in self._fetch_all():
                 result.extend(resolve_nested(record, done))
             del resolve_nested
             return result
-        for name in wildcard.strings:
-            result.extend(resolve_nested(self.find(name), done))
+        if wildcard.strings:
+            for record in self._find_many(wildcard.strings):
+                result.extend(resolve_nested(record, done))
         if wildcard.patterns:
-            for record in self._records.values():
+            for record in self._fetch_all():
                 if any(p.fullmatch(record.name) for p in wildcard.patterns):
                     result.extend(resolve_nested(record, done))
         del resolve_nested
         return result
 
-    def getDocumentation(self, key: Any) -> str | None:
+    def getDocumentation(self, key: K) -> str | None:
         # Docstring inherited from CollectionManager.
         sql = (
             sqlalchemy.sql.select(self._tables.collection.columns.doc)
@@ -513,27 +371,76 @@ class DefaultCollectionManager(Generic[K], CollectionManager):
         with self._db.query(sql) as sql_result:
             return sql_result.scalar()
 
-    def setDocumentation(self, key: Any, doc: str | None) -> None:
+    def setDocumentation(self, key: K, doc: str | None) -> None:
         # Docstring inherited from CollectionManager.
         self._db.update(self._tables.collection, {self._collectionIdName: "key"}, {"key": key, "doc": doc})
 
-    def _setRecordCache(self, records: Iterable[CollectionRecord]) -> None:
-        """Set internal record cache to contain given records,
-        old cached records will be removed.
-        """
-        self._records = {}
-        for record in records:
-            self._records[record.key] = record
-
-    def _addCachedRecord(self, record: CollectionRecord) -> None:
+    def _addCachedRecord(self, record: CollectionRecord[K]) -> None:
         """Add single record to cache."""
-        self._records[record.key] = record
+        if self._caching_context.collection_records is not None:
+            self._caching_context.collection_records.add(record)
 
-    def _removeCachedRecord(self, record: CollectionRecord) -> None:
+    def _removeCachedRecord(self, record: CollectionRecord[K]) -> None:
         """Remove single record from cache."""
-        del self._records[record.key]
+        if self._caching_context.collection_records is not None:
+            self._caching_context.collection_records.discard(record)
+
+    def _getByName(self, name: str) -> CollectionRecord[K] | None:
+        """Find collection record given collection name."""
+        if self._caching_context.collection_records is not None:
+            if (record := self._caching_context.collection_records.get_by_name(name)) is not None:
+                return record
+        records = self._fetch_by_name([name])
+        for record in records:
+            self._addCachedRecord(record)
+        return records[0] if records else None
 
     @abstractmethod
-    def _getByName(self, name: str) -> CollectionRecord | None:
-        """Find collection record given collection name."""
+    def _fetch_by_name(self, names: Iterable[str]) -> list[CollectionRecord[K]]:
+        """Fetch collection record from database given its name."""
         raise NotImplementedError()
+
+    @abstractmethod
+    def _fetch_by_key(self, collection_ids: Iterable[K] | None) -> list[CollectionRecord[K]]:
+        """Fetch collection record from database given its key, or fetch all
+        collctions if argument is None.
+        """
+        raise NotImplementedError()
+
+    def update_chain(
+        self, chain: ChainedCollectionRecord[K], children: Iterable[str], flatten: bool = False
+    ) -> ChainedCollectionRecord[K]:
+        # Docstring inherited from CollectionManager.
+        children_as_wildcard = CollectionWildcard.from_names(children)
+        for record in self.resolve_wildcard(
+            children_as_wildcard,
+            flatten_chains=True,
+            include_chains=True,
+            collection_types={CollectionType.CHAINED},
+        ):
+            if record == chain:
+                raise ValueError(f"Cycle in collection chaining when defining '{chain.name}'.")
+        if flatten:
+            children = tuple(
+                record.name for record in self.resolve_wildcard(children_as_wildcard, flatten_chains=True)
+            )
+
+        rows = []
+        position = itertools.count()
+        names = []
+        for child in self.resolve_wildcard(CollectionWildcard.from_names(children), flatten_chains=False):
+            rows.append(
+                {
+                    "parent": chain.key,
+                    "child": child.key,
+                    "position": next(position),
+                }
+            )
+            names.append(child.name)
+        with self._db.transaction():
+            self._db.delete(self._tables.collection_chain, ["parent"], {"parent": chain.key})
+            self._db.insert(self._tables.collection_chain, *rows)
+
+        record = ChainedCollectionRecord[K](chain.key, chain.name, children=tuple(names))
+        self._addCachedRecord(record)
+        return record
