@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -27,7 +33,7 @@ import datetime
 import types
 import warnings
 from collections.abc import Mapping, Set
-from typing import Any, Union, cast
+from typing import Any, cast
 
 import astropy.time
 import astropy.utils.exceptions
@@ -41,20 +47,12 @@ from lsst.daf.relation import (
     sql,
 )
 
-# We import the timespan module rather than types within it because match
-# syntax uses qualified names with periods to distinguish literals from
-# captures.
-from ....core import (
-    ColumnTypeInfo,
-    DataCoordinate,
-    DatasetColumnTag,
-    Dimension,
-    DimensionGraph,
-    DimensionKeyColumnTag,
-    DimensionRecordColumnTag,
-    DimensionUniverse,
-    timespan,
-)
+# We import the some modules rather than types within them because match syntax
+# uses qualified names with periods to distinguish literals from captures.
+from .... import _timespan, timespan_database_representation
+from ...._column_tags import DatasetColumnTag, DimensionKeyColumnTag, DimensionRecordColumnTag
+from ...._column_type_info import ColumnTypeInfo
+from ....dimensions import DataCoordinate, Dimension, DimensionGroup, DimensionUniverse
 from ..._exceptions import UserExpressionError, UserExpressionSyntaxError
 from .categorize import ExpressionConstant, categorizeConstant, categorizeElementId
 from .check import CheckVisitor
@@ -77,7 +75,7 @@ class ExpressionTypeError(TypeError):
 
 def make_string_expression_predicate(
     string: str,
-    dimensions: DimensionGraph,
+    dimensions: DimensionGroup,
     *,
     column_types: ColumnTypeInfo,
     bind: Mapping[str, Any] | None = None,
@@ -92,12 +90,12 @@ def make_string_expression_predicate(
     ----------
     string : `str`
         String to parse.
-    dimensions : `DimensionGraph`
+    dimensions : `DimensionGroup`
         The dimensions the query would include in the absence of this WHERE
         expression.
     column_types : `ColumnTypeInfo`
         Information about column types.
-    bind : `Mapping` [ `str`, `Any` ], optional
+    bind : `~collections.abc.Mapping` [ `str`, `Any` ], optional
         Literal values referenced in the expression.
     data_id : `DataCoordinate`, optional
         A fully-expanded data ID identifying dimensions known in advance.
@@ -120,16 +118,17 @@ def make_string_expression_predicate(
     predicate : `lsst.daf.relation.colum_expressions.Predicate` or `None`
         New predicate derived from the string expression, or `None` if the
         string is empty.
-    governor_constraints : `Mapping` [ `str` , `~collections.abc.Set` ]
+    governor_constraints : `~collections.abc.Mapping` [ `str` , \
+            `~collections.abc.Set` ]
         Constraints on dimension values derived from the expression and data
         ID.
     """
     governor_constraints: dict[str, Set[str]] = {}
     if data_id is None:
-        data_id = DataCoordinate.makeEmpty(dimensions.universe)
+        data_id = DataCoordinate.make_empty(dimensions.universe)
     if not string:
-        for dimension in data_id.graph.governors:
-            governor_constraints[dimension.name] = {cast(str, data_id[dimension])}
+        for dimension in data_id.dimensions.governors:
+            governor_constraints[dimension] = {cast(str, data_id[dimension])}
         return None, governor_constraints
     try:
         parser = ParserYacc()
@@ -140,13 +139,13 @@ def make_string_expression_predicate(
         bind = {}
     if bind:
         for identifier in bind:
-            if identifier in dimensions.universe.getStaticElements().names:
+            if identifier in dimensions.universe.elements.names:
                 raise RuntimeError(f"Bind parameter key {identifier!r} conflicts with a dimension element.")
             table, _, column = identifier.partition(".")
-            if column and table in dimensions.universe.getStaticElements().names:
+            if column and table in dimensions.universe.elements.names:
                 raise RuntimeError(f"Bind parameter key {identifier!r} looks like a dimension column.")
     if defaults is None:
-        defaults = DataCoordinate.makeEmpty(dimensions.universe)
+        defaults = DataCoordinate.make_empty(dimensions.universe)
     # Convert the expression to disjunctive normal form (ORs of ANDs).
     # That's potentially super expensive in the general case (where there's
     # a ton of nesting of ANDs and ORs).  That won't be the case for the
@@ -168,14 +167,14 @@ def make_string_expression_predicate(
             msg = f'Error in query expression "{exprOriginal}" (normalized to "{exprNormal}"): {err}'
         raise UserExpressionError(msg) from None
     for dimension_name, values in summary.dimension_constraints.items():
-        if dimension_name in dimensions.universe.getGovernorDimensions().names:
+        if dimension_name in dimensions.universe.governor_dimensions.names:
             governor_constraints[dimension_name] = cast(Set[str], values)
     converter = PredicateConversionVisitor(bind, dataset_type_name, dimensions.universe, column_types)
     predicate = tree.visit(converter)
     return predicate, governor_constraints
 
 
-VisitorResult = Union[Predicate, ColumnExpression, ColumnContainer]
+VisitorResult = Predicate | ColumnExpression | ColumnContainer
 
 
 class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
@@ -276,13 +275,13 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
             case [
                 "<",
                 ColumnExpression(dtype=astropy.time.Time) as lhs,
-                ColumnExpression(dtype=timespan.Timespan) as rhs,
+                ColumnExpression(dtype=_timespan.Timespan) as rhs,
             ]:
                 return rhs.predicate_method(self.OPERATOR_MAP[">"], lhs)
             case [
                 ">",
                 ColumnExpression(dtype=astropy.time.Time) as lhs,
-                ColumnExpression(dtype=timespan.Timespan) as rhs,
+                ColumnExpression(dtype=_timespan.Timespan) as rhs,
             ]:
                 return rhs.predicate_method(self.OPERATOR_MAP["<"], lhs)
             # Enable other comparisons between times and Timespans (many of the
@@ -290,8 +289,8 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
             # covered by a preceding branch).
             case [
                 "<" | ">",
-                ColumnExpression(dtype=timespan.Timespan | astropy.time.Time) as lhs,
-                ColumnExpression(dtype=timespan.Timespan | astropy.time.Time) as rhs,
+                ColumnExpression(dtype=_timespan.Timespan | astropy.time.Time) as lhs,
+                ColumnExpression(dtype=_timespan.Timespan | astropy.time.Time) as rhs,
             ]:
                 return lhs.predicate_method(self.OPERATOR_MAP[operator], rhs)
             # Enable "overlaps" operations between timespans, and between times
@@ -300,20 +299,20 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
             # OVERLAPS in the string expression language to keep that simple.
             case [
                 "OVERLAPS",
-                ColumnExpression(dtype=timespan.Timespan) as lhs,
-                ColumnExpression(dtype=timespan.Timespan) as rhs,
+                ColumnExpression(dtype=_timespan.Timespan) as lhs,
+                ColumnExpression(dtype=_timespan.Timespan) as rhs,
             ]:
                 return lhs.predicate_method("overlaps", rhs)
             case [
                 "OVERLAPS",
-                ColumnExpression(dtype=timespan.Timespan) as lhs,
+                ColumnExpression(dtype=_timespan.Timespan) as lhs,
                 ColumnExpression(dtype=astropy.time.Time) as rhs,
             ]:
                 return lhs.predicate_method("overlaps", rhs)
             case [
                 "OVERLAPS",
                 ColumnExpression(dtype=astropy.time.Time) as lhs,
-                ColumnExpression(dtype=timespan.Timespan) as rhs,
+                ColumnExpression(dtype=_timespan.Timespan) as rhs,
             ]:
                 return rhs.predicate_method("overlaps", lhs)
             # Enable arithmetic operators on numeric types, without any type
@@ -354,7 +353,7 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
         # Docstring inherited.
         if name in self.bind:
             value = self.bind[name]
-            if isinstance(value, (list, tuple, Set)):
+            if isinstance(value, list | tuple | Set):
                 elements = []
                 all_dtypes = set()
                 for item in value:
@@ -388,8 +387,8 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
         if column is not None:
             tag = DimensionRecordColumnTag(element.name, column)
             dtype = (
-                timespan.Timespan
-                if column == timespan.TimespanDatabaseRepresentation.NAME
+                _timespan.Timespan
+                if column == timespan_database_representation.TimespanDatabaseRepresentation.NAME
                 else element.RecordClass.fields.standard[column].getPythonType()
             )
             return ColumnExpression.reference(tag, dtype)
@@ -463,7 +462,7 @@ class PredicateConversionVisitor(TreeVisitor[VisitorResult]):
                 ColumnLiteral(value=begin, dtype=astropy.time.Time | types.NoneType),
                 ColumnLiteral(value=end, dtype=astropy.time.Time | types.NoneType),
             ]:
-                return ColumnExpression.literal(timespan.Timespan(begin, end), dtype=timespan.Timespan)
+                return ColumnExpression.literal(_timespan.Timespan(begin, end), dtype=_timespan.Timespan)
         raise ExpressionTypeError(
             f'Invalid type(s) ({items[0].dtype}, {items[1].dtype}) in timespan tuple "{node}" '
             '(Note that date/time strings must be preceded by "T" to be recognized).'
