@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -58,7 +64,7 @@ class ConfigValidateUseTest(unittest.TestCase):
             # verify the just-created repo validates without error
             result = self.runner.invoke(butler.cli, ["config-validate", "here"])
             self.assertEqual(result.exit_code, 0, result.stdout)
-            self.assertEqual(result.stdout, "No problems encountered with configuration.\n")
+            self.assertIn("No problems encountered with configuration.", result.stdout)
 
     def testConfigValidate_ignore(self):
         """Test the ignore flag"""
@@ -78,7 +84,7 @@ class ConfigValidateUseTest(unittest.TestCase):
                 ],
             )
             self.assertEqual(result.exit_code, 0, result.stdout)
-            self.assertEqual(result.stdout, "No problems encountered with configuration.\n")
+            self.assertIn("No problems encountered with configuration.", result.stdout)
 
 
 if __name__ == "__main__":
