@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -26,10 +32,9 @@ import unittest
 from unittest.mock import patch
 
 # Tests require the SqlRegistry
-import lsst.daf.butler.registries.sql
+import lsst.daf.butler.registry.sql_registry
 import lsst.daf.butler.script
 from astropy.table import Table
-from lsst.daf.butler import Butler
 from lsst.daf.butler.cli.butler import cli as butlerCli
 from lsst.daf.butler.cli.cmd.commands import (
     pruneDatasets_askContinueMsg,
@@ -48,6 +53,7 @@ from lsst.daf.butler.cli.cmd.commands import (
     pruneDatasets_wouldRemoveMsg,
 )
 from lsst.daf.butler.cli.utils import LogCliRunner, astropyTablesToStr, clickResultMsg
+from lsst.daf.butler.direct_butler import DirectButler
 from lsst.daf.butler.registry import CollectionType
 from lsst.daf.butler.script import QueryDatasets
 
@@ -112,7 +118,7 @@ class PruneDatasetsTestCase(unittest.TestCase):
     @patch.object(lsst.daf.butler.script._pruneDatasets, "QueryDatasets", side_effect=makeQueryDatasets)
     # Mock the pruneDatasets butler command so we can test for expected calls
     # to it, without dealing with setting up a full repo with data for it.
-    @patch.object(Butler, "pruneDatasets")
+    @patch.object(DirectButler, "pruneDatasets")
     def run_test(
         self,
         mockPruneDatasets,
@@ -394,7 +400,7 @@ class PruneDatasetsTestCase(unittest.TestCase):
         )
 
     @patch.object(
-        lsst.daf.butler.registries.sql.SqlRegistry,
+        lsst.daf.butler.registry.sql_registry.SqlRegistry,
         "getCollectionType",
         side_effect=lambda x: CollectionType.RUN,
     )
@@ -426,7 +432,7 @@ class PruneDatasetsTestCase(unittest.TestCase):
         )
 
     @patch.object(
-        lsst.daf.butler.registries.sql.SqlRegistry,
+        lsst.daf.butler.registry.sql_registry.SqlRegistry,
         "getCollectionType",
         side_effect=lambda x: CollectionType.RUN,
     )
@@ -451,7 +457,7 @@ class PruneDatasetsTestCase(unittest.TestCase):
         )
 
     @patch.object(
-        lsst.daf.butler.registries.sql.SqlRegistry,
+        lsst.daf.butler.registry.sql_registry.SqlRegistry,
         "getCollectionType",
         side_effect=lambda x: CollectionType.TAGGED,
     )
