@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -92,7 +98,7 @@ class QueryCollectionsScriptTest(ButlerTestHelper, unittest.TestCase):
         with self.runner.isolated_filesystem():
             butlerCfg = Butler.makeRepo("here")
             # the purpose of this call is to create some collections
-            butler = Butler(butlerCfg, run=run, collections=[tag], writeable=True)
+            butler = Butler.from_config(butlerCfg, run=run, collections=[tag], writeable=True)
             butler.registry.registerCollection(tag, CollectionType.TAGGED)
 
             # Verify collections that were created are found by
@@ -134,7 +140,7 @@ class ChainedCollectionsTest(ButlerTestHelper, unittest.TestCase):
             # Create a butler and add some chained collections:
             butlerCfg = Butler.makeRepo("here")
 
-            butler1 = Butler(butlerCfg, writeable=True)
+            butler1 = Butler.from_config(butlerCfg, writeable=True)
 
             # Replace datastore functions with mocks:
             DatastoreMock.apply(butler1)
