@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -27,6 +33,7 @@ import unittest
 
 from astropy.table import Table as AstropyTable
 from lsst.daf.butler import Butler, DatasetType, script
+from lsst.daf.butler.direct_butler import DirectButler
 from lsst.daf.butler.tests.utils import ButlerTestHelper, makeTestTempDir, removeTestTempDir
 from lsst.daf.butler.transfers import YamlRepoImportBackend
 from numpy import array
@@ -64,13 +71,14 @@ class QueryDataIdsTest(unittest.TestCase, ButlerTestHelper):
         """Load registry test data from ``TESTDIR/data/registry/<filename>``,
         which should be a YAML import/export file.
         """
-        butler = Butler(self.repo, writeable=True)
+        butler = Butler.from_config(self.repo, writeable=True)
+        assert isinstance(butler, DirectButler), "Test expects DirectButler"
         for filename in filenames:
             with open(os.path.join(TESTDIR, "data", "registry", filename)) as stream:
                 # Go behind the back of the import code a bit to deal with
                 # the fact that this is just registry content with no actual
                 # files for the datastore.
-                backend = YamlRepoImportBackend(stream, butler.registry)
+                backend = YamlRepoImportBackend(stream, butler._registry)
                 backend.register()
                 backend.load(datastore=None)
         return butler
@@ -137,7 +145,7 @@ class QueryDataIdsTest(unittest.TestCase, ButlerTestHelper):
 
     def testDatasetsAndCollections(self):
         """Test constraining via datasets and collections."""
-        butler = self.loadData("base.yaml", "datasets-uuid.yaml")
+        butler = self.loadData("base.yaml", "datasets.yaml")
         # See that the data IDs returned are constrained by that collection's
         # contents.
         res, msg = self._queryDataIds(
@@ -172,14 +180,6 @@ class QueryDataIdsTest(unittest.TestCase, ButlerTestHelper):
         self.assertIsNone(res)
         self.assertIn("No dimensions in common", msg)
 
-        # Check that we get a reason returned if no dataset type is found.
-        with self.assertWarns(FutureWarning):
-            res, msg = self._queryDataIds(
-                repo=self.root, dimensions=("detector",), collections=("imported_g",), datasets="raw"
-            )
-        self.assertIsNone(res)
-        self.assertEqual(msg, "Dataset type raw is not registered.")
-
         # Check that we get a reason returned if no dataset is found in
         # collection.
         res, msg = self._queryDataIds(
