@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -40,7 +46,7 @@ class QueryDatasetTypesCmdTest(CliCmdTestBase, unittest.TestCase):
 
     @staticmethod
     def defaultExpected():
-        return dict(repo=None, verbose=False, glob=(), components=False)
+        return dict(repo=None, verbose=False, glob=())
 
     @staticmethod
     def command():
@@ -57,12 +63,12 @@ class QueryDatasetTypesCmdTest(CliCmdTestBase, unittest.TestCase):
     def test_all(self):
         """Test all parameters."""
         self.run_test(
-            ["query-dataset-types", "here", "--verbose", "foo*", "--components"],
-            self.makeExpected(repo="here", verbose=True, glob=("foo*",), components=True),
+            ["query-dataset-types", "here", "--verbose", "foo*"],
+            self.makeExpected(repo="here", verbose=True, glob=("foo*",)),
         )
         self.run_test(
-            ["query-dataset-types", "here", "--verbose", "foo*", "--no-components"],
-            self.makeExpected(repo="here", verbose=True, glob=("foo*",), components=False),
+            ["query-dataset-types", "here", "--verbose", "foo*"],
+            self.makeExpected(repo="here", verbose=True, glob=("foo*",)),
         )
 
 
