@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -44,10 +50,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.data",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "423",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.data/"
                             "test_metric_comp_v00000423_fDummyCamComp_data.yaml"
@@ -56,10 +62,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.data",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "424",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.data/"
                             "test_metric_comp_v00000424_fDummyCamComp_data.yaml"
@@ -67,7 +73,7 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     ),
                 )
             ),
-            names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+            names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
         ),
         AstropyTable(
             array(
@@ -75,10 +81,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.output",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "423",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.output/"
                             "test_metric_comp_v00000423_fDummyCamComp_output.yaml"
@@ -87,10 +93,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.output",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "424",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.output/"
                             "test_metric_comp_v00000424_fDummyCamComp_output.yaml"
@@ -98,7 +104,7 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     ),
                 )
             ),
-            names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+            names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
         ),
         AstropyTable(
             array(
@@ -106,10 +112,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.summary",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "423",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.summary/"
                             "test_metric_comp_v00000423_fDummyCamComp_summary.yaml"
@@ -118,10 +124,10 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     (
                         "test_metric_comp.summary",
                         "ingest/run",
-                        "R",
                         "DummyCamComp",
-                        "d-r",
                         "424",
+                        "R",
+                        "d-r",
                         root.join(
                             "ingest/run/test_metric_comp.summary/"
                             "test_metric_comp_v00000424_fDummyCamComp_summary.yaml"
@@ -129,7 +135,7 @@ def expectedFilesystemDatastoreTables(root: ResourcePath):
                     ),
                 )
             ),
-            names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+            names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
         ),
     )
 
@@ -191,11 +197,11 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
             AstropyTable(
                 array(
                     (
-                        ("test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "423"),
-                        ("test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "424"),
+                        ("test_metric_comp", "ingest/run", "DummyCamComp", "423", "R", "d-r"),
+                        ("test_metric_comp", "ingest/run", "DummyCamComp", "424", "R", "d-r"),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter"),
             ),
         )
 
@@ -211,8 +217,8 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
 
         expectedTables = (
             AstropyTable(
-                array(("test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "423")),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit"),
+                array(("test_metric_comp", "ingest/run", "DummyCamComp", "423", "R", "d-r")),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter"),
             ),
         )
 
@@ -241,15 +247,15 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
             AstropyTable(
                 array(
                     (
-                        ("test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "423"),
-                        ("test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "424"),
+                        ("test_metric_comp", "ingest/run", "DummyCamComp", "423", "R", "d-r"),
+                        ("test_metric_comp", "ingest/run", "DummyCamComp", "424", "R", "d-r"),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter"),
             ),
             AstropyTable(
-                array(("alt_test_metric_comp", "ingest/run", "R", "DummyCamComp", "d-r", "425")),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit"),
+                array(("alt_test_metric_comp", "ingest/run", "DummyCamComp", "425", "R", "d-r")),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter"),
             ),
         )
 
@@ -279,10 +285,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.data",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.data/test_metric_comp_v00000424_fDummyCamComp_data.yaml"
                             ),
@@ -290,10 +296,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.data",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.data/"
                                 "test_metric_comp_v00000423_fDummyCamComp_data.yaml"
@@ -302,10 +308,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.data",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.data/"
                                 "test_metric_comp_v00000424_fDummyCamComp_data.yaml"
@@ -313,7 +319,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
             AstropyTable(
                 array(
@@ -321,10 +327,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.output",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.output/"
                                 "test_metric_comp_v00000424_fDummyCamComp_output.yaml"
@@ -333,10 +339,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.output",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.output/"
                                 "test_metric_comp_v00000423_fDummyCamComp_output.yaml"
@@ -345,10 +351,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.output",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.output/"
                                 "test_metric_comp_v00000424_fDummyCamComp_output.yaml"
@@ -356,7 +362,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
             AstropyTable(
                 array(
@@ -364,10 +370,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.summary",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.summary/"
                                 "test_metric_comp_v00000424_fDummyCamComp_summary.yaml"
@@ -376,10 +382,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.summary",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.summary/"
                                 "test_metric_comp_v00000423_fDummyCamComp_summary.yaml"
@@ -388,10 +394,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.summary",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.summary/"
                                 "test_metric_comp_v00000424_fDummyCamComp_summary.yaml"
@@ -399,7 +405,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
         )
 
@@ -418,10 +424,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.data",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.data/test_metric_comp_v00000424_fDummyCamComp_data.yaml"
                             ),
@@ -429,10 +435,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.data",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.data/"
                                 "test_metric_comp_v00000423_fDummyCamComp_data.yaml"
@@ -440,7 +446,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
             AstropyTable(
                 array(
@@ -448,10 +454,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.output",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.output/"
                                 "test_metric_comp_v00000424_fDummyCamComp_output.yaml"
@@ -460,10 +466,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.output",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.output/"
                                 "test_metric_comp_v00000423_fDummyCamComp_output.yaml"
@@ -471,7 +477,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
             AstropyTable(
                 array(
@@ -479,10 +485,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.summary",
                             "foo",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "424",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "foo/test_metric_comp.summary/"
                                 "test_metric_comp_v00000424_fDummyCamComp_summary.yaml"
@@ -491,10 +497,10 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         (
                             "test_metric_comp.summary",
                             "ingest/run",
-                            "R",
                             "DummyCamComp",
-                            "d-r",
                             "423",
+                            "R",
+                            "d-r",
                             datastore_root.join(
                                 "ingest/run/test_metric_comp.summary/"
                                 "test_metric_comp_v00000423_fDummyCamComp_summary.yaml"
@@ -502,7 +508,7 @@ class QueryDatasetsTest(unittest.TestCase, ButlerTestHelper):
                         ),
                     )
                 ),
-                names=("type", "run", "band", "instrument", "physical_filter", "visit", "URI"),
+                names=("type", "run", "instrument", "visit", "band", "physical_filter", "URI"),
             ),
         )
 
