@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -25,9 +31,7 @@
 import os
 import unittest
 
-import astropy
 from astropy.table import Table as AstropyTable
-from astropy.utils.introspection import minversion
 from lsst.daf.butler import Butler, StorageClassFactory
 from lsst.daf.butler.cli.butler import cli as butlerCli
 from lsst.daf.butler.cli.utils import LogCliRunner, clickResultMsg
@@ -42,10 +46,6 @@ from numpy import array
 
 TESTDIR = os.path.abspath(os.path.dirname(__file__))
 
-# Astropy changed the handling of numpy columns in v5.1 so anything
-# greater than 5.0 (two digit version) does not need the annotated column.
-timespan_columns = "" if minversion(astropy, "5.1") else " [2]"
-
 
 class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
     """Test the query-dimension-records command-line."""
@@ -69,7 +69,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
         "azimuth",
         "zenith_angle",
         "region",
-        f"timespan{timespan_columns}",
+        "timespan (TAI)",
     )
 
     def setUp(self):
@@ -101,7 +101,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "[2020-01-01T08:00:00, 2020-01-01T08:00:36)",
                 ),
                 (
                     "DummyCamComp",
@@ -117,12 +117,13 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "None",
                 ),
             )
         )
         expected = AstropyTable(rows, names=self.expectedColumnNames)
-        self.assertAstropyTablesEqual(readTable(result.output), expected)
+        got = readTable(result.output)
+        self.assertAstropyTablesEqual(got, expected)
 
     def testWhere(self):
         result = self.runner.invoke(
@@ -152,7 +153,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "[2020-01-01T08:00:00, 2020-01-01T08:00:36)",
                 ),
             )
         )
@@ -160,7 +161,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
         self.assertAstropyTablesEqual(readTable(result.output), expected)
 
     def testCollection(self):
-        butler = Butler(self.root, run="foo")
+        butler = Butler.from_config(self.root, run="foo")
 
         # try replacing the testRepo's butler with the one with the "foo" run.
         self.testRepo.butler = butler
@@ -206,7 +207,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "[2020-01-01T08:00:00, 2020-01-01T08:00:36)",
                 ),
                 (
                     "DummyCamComp",
@@ -222,7 +223,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "None",
                 ),
             )
         )
@@ -259,7 +260,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
                     "None",
                     "None",
                     "None",
-                    "None .. None",
+                    "None",
                 ),
             )
         )
@@ -267,7 +268,7 @@ class QueryDimensionRecordsTest(unittest.TestCase, ButlerTestHelper):
         self.assertAstropyTablesEqual(readTable(result.output), expected)
 
     def testSkymap(self):
-        butler = Butler(self.root, run="foo")
+        butler = Butler.from_config(self.root, run="foo")
         # try replacing the testRepo's butler with the one with the "foo" run.
         self.testRepo.butler = butler
 
