@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -25,6 +31,7 @@
 import glob
 import os
 import os.path
+import tempfile
 import unittest
 
 import lsst.daf.butler.registry.connectionString as ConnectionStringModule
@@ -74,11 +81,15 @@ class ConnectionStringBuilderTestCase(unittest.TestCase):
 
     def testRaises(self):
         """Test that DbAuthError propagates through the class."""
-        ConnectionStringModule.DB_AUTH_PATH = os.path.join(self.configDir, "badDbAuth2.yaml")
-        regConf = RegistryConfig(os.path.join(self.configDir, "registryConf2.yaml"))
-        conStrFactory = ConnectionStringFactory()
-        with self.assertRaises(DbAuthError):
-            conStrFactory.fromConfig(regConf)
+        # Create a bad yaml file that triggers a parsing error.
+        # It will be created with the correct 600 permissions.
+        with tempfile.NamedTemporaryFile(suffix=".yaml", mode="w") as temp_config:
+            print("[", file=temp_config, flush=True)
+            ConnectionStringModule.DB_AUTH_PATH = os.path.join(temp_config.name)
+            regConf = RegistryConfig(os.path.join(self.configDir, "registryConf2.yaml"))
+            conStrFactory = ConnectionStringFactory()
+            with self.assertRaises(DbAuthError):
+                conStrFactory.fromConfig(regConf)
 
 
 if __name__ == "__main__":
