@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -39,22 +45,21 @@ from lsst.daf.butler import (
     DataCoordinate,
     DatasetIdGenEnum,
     DatasetRef,
-    DatasetRefURIs,
     DatasetType,
     DatasetTypeNotSupportedError,
     Datastore,
-    DatastoreCacheManager,
-    DatastoreCacheManagerConfig,
-    DatastoreConfig,
-    DatastoreDisabledCacheManager,
-    DatastoreValidationError,
     DimensionUniverse,
     FileDataset,
-    NullDatastore,
     StorageClass,
     StorageClassFactory,
-    StoredFileInfo,
 )
+from lsst.daf.butler.datastore import DatasetRefURIs, DatastoreConfig, DatastoreValidationError, NullDatastore
+from lsst.daf.butler.datastore.cache_manager import (
+    DatastoreCacheManager,
+    DatastoreCacheManagerConfig,
+    DatastoreDisabledCacheManager,
+)
+from lsst.daf.butler.datastore.stored_file_info import StoredFileInfo
 from lsst.daf.butler.formatters.yaml import YamlFormatter
 from lsst.daf.butler.tests import (
     BadNoWriteFormatter,
@@ -156,7 +161,7 @@ class DatastoreTests(DatastoreTestsBase):
             with self.assertRaises(DatastoreValidationError):
                 datastore.validateConfiguration([sc2], logFailures=True)
 
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
         ref = self.makeDatasetRef("metric", dimensions, sc, dataId)
         datastore.validateConfiguration([ref])
@@ -164,7 +169,7 @@ class DatastoreTests(DatastoreTestsBase):
     def testParameterValidation(self) -> None:
         """Check that parameters are validated"""
         sc = self.storageClassFactory.getStorageClass("ThingOne")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
         ref = self.makeDatasetRef("metric", dimensions, sc, dataId)
         datastore = self.makeDatastore()
@@ -185,7 +190,7 @@ class DatastoreTests(DatastoreTestsBase):
             for sc in ("StructuredData", "StructuredDataJson", "StructuredDataPickle")
         ]
 
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
         dataId2 = {"instrument": "dummy", "visit": 53, "physical_filter": "V", "band": "v"}
 
@@ -304,7 +309,7 @@ class DatastoreTests(DatastoreTestsBase):
             # Create multiple storage classes for testing with or without
             # disassembly
             sc = self.storageClassFactory.getStorageClass(sc_name)
-            dimensions = self.universe.extract(("visit", "physical_filter"))
+            dimensions = self.universe.conform(("visit", "physical_filter"))
 
             dataId = {"instrument": "dummy", "visit": 52 + i, "physical_filter": "V", "band": "v"}
 
@@ -452,7 +457,7 @@ class DatastoreTests(DatastoreTestsBase):
         datastore = self.makeDatastore()
 
         # Dummy dataId
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 428, "physical_filter": "R"}
 
         for i, sc in enumerate(storageClasses):
@@ -504,7 +509,7 @@ class DatastoreTests(DatastoreTestsBase):
         metrics = makeExampleMetrics()
         datastore = self.makeDatastore()
         # Put
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         sc = self.storageClassFactory.getStorageClass("StructuredData")
         refs = []
         for i in range(n_refs):
@@ -568,7 +573,7 @@ class DatastoreTests(DatastoreTestsBase):
     def testTransfer(self) -> None:
         metrics = makeExampleMetrics()
 
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 2048, "physical_filter": "Uprime", "band": "u"}
 
         sc = self.storageClassFactory.getStorageClass("StructuredData")
@@ -586,7 +591,7 @@ class DatastoreTests(DatastoreTestsBase):
     def testBasicTransaction(self) -> None:
         datastore = self.makeDatastore()
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         nDatasets = 6
         dataIds = [
             {"instrument": "dummy", "visit": i, "physical_filter": "V", "band": "v"} for i in range(nDatasets)
@@ -632,7 +637,7 @@ class DatastoreTests(DatastoreTestsBase):
     def testNestedTransaction(self) -> None:
         datastore = self.makeDatastore()
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         metrics = makeExampleMetrics()
 
         dataId = {"instrument": "dummy", "visit": 0, "physical_filter": "V", "band": "v"}
@@ -664,7 +669,7 @@ class DatastoreTests(DatastoreTestsBase):
 
     def _prepareIngestTest(self) -> tuple[MetricsExample, DatasetRef]:
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         metrics = makeExampleMetrics()
         dataId = {"instrument": "dummy", "visit": 0, "physical_filter": "V", "band": "v"}
         ref = self.makeDatasetRef("metric", dimensions, storageClass, dataId)
@@ -860,7 +865,7 @@ class DatastoreTests(DatastoreTestsBase):
             raise unittest.SkipTest("in-memory datastore does not support record export/import")
 
         metrics = makeExampleMetrics()
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         sc = self.storageClassFactory.getStorageClass("StructuredData")
 
         refs = []
@@ -925,7 +930,7 @@ class DatastoreTests(DatastoreTestsBase):
         # Create a new ref that is not known to the datastore and try to
         # export it.
         sc = self.storageClassFactory.getStorageClass("ThingOne")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
         ref = self.makeDatasetRef("metric", dimensions, sc, dataId)
         with self.assertRaises(FileNotFoundError):
@@ -940,7 +945,7 @@ class DatastoreTests(DatastoreTestsBase):
             "store_as_model",
             dimensions=self.universe.empty,
             storageClass="DictConvertibleModel",
-            dataId=DataCoordinate.makeEmpty(self.universe),
+            dataId=DataCoordinate.make_empty(self.universe),
         )
         content = {"a": "one", "b": "two"}
         model = DictConvertibleModel.from_dict(content, extra="original content")
@@ -983,7 +988,7 @@ class DatastoreTests(DatastoreTestsBase):
                 f"stora_as_{x}",
                 dimensions=self.universe.empty,
                 storageClass=f"{storageClass_root}{x}",
-                dataId=DataCoordinate.makeEmpty(self.universe),
+                dataId=DataCoordinate.make_empty(self.universe),
             )
             for x in ["A", "B"]
         }
@@ -1014,7 +1019,7 @@ class PosixDatastoreTestCase(DatastoreTests, unittest.TestCase):
         """Test that we write to a temporary and then rename"""
         datastore = self.makeDatastore()
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         metrics = makeExampleMetrics()
 
         dataId = {"instrument": "dummy", "visit": 0, "physical_filter": "V", "band": "v"}
@@ -1043,7 +1048,7 @@ class PosixDatastoreTestCase(DatastoreTests, unittest.TestCase):
             "StructuredComposite", components={"dummy": sccomp, "dummy2": sccomp}
         )
 
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
 
         ref = self.makeDatasetRef("metric", dimensions, storageClass, dataId)
@@ -1083,7 +1088,7 @@ class PosixDatastoreNoChecksumsTestCase(PosixDatastoreTestCase):
         """Ensure that checksums have not been calculated."""
         datastore = self.makeDatastore()
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         metrics = makeExampleMetrics()
 
         dataId = {"instrument": "dummy", "visit": 0, "physical_filter": "V", "band": "v"}
@@ -1195,7 +1200,7 @@ class CleanupPosixDatastoreTestCase(DatastoreTestsBase, unittest.TestCase):
 
         storageClass = self.storageClassFactory.getStorageClass("StructuredData")
 
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
 
         ref = self.makeDatasetRef("metric", dimensions, storageClass, dataId)
@@ -1276,7 +1281,7 @@ class DatastoreConstraintsTests(DatastoreTestsBase):
 
         sc1 = self.storageClassFactory.getStorageClass("StructuredData")
         sc2 = self.storageClassFactory.getStorageClass("StructuredDataJson")
-        dimensions = self.universe.extract(("visit", "physical_filter", "instrument"))
+        dimensions = self.universe.conform(("visit", "physical_filter", "instrument"))
         dataId = {"visit": 52, "physical_filter": "V", "band": "v", "instrument": "DummyCamComp"}
 
         # Write empty file suitable for ingest check (JSON and YAML variants)
@@ -1374,7 +1379,7 @@ class ChainedDatastorePerStoreConstraintsTests(DatastoreTestsBase, unittest.Test
 
         sc1 = self.storageClassFactory.getStorageClass("StructuredData")
         sc2 = self.storageClassFactory.getStorageClass("StructuredDataJson")
-        dimensions = self.universe.extract(("visit", "physical_filter", "instrument"))
+        dimensions = self.universe.conform(("visit", "physical_filter", "instrument"))
         dataId1 = {"visit": 52, "physical_filter": "V", "band": "v", "instrument": "DummyCamComp"}
         dataId2 = {"visit": 52, "physical_filter": "V", "band": "v", "instrument": "HSC"}
 
@@ -1461,7 +1466,7 @@ class DatastoreCacheTestCase(DatasetTestHelper, unittest.TestCase):
 
         # Create some test dataset refs and associated test files
         sc = self.storageClassFactory.getStorageClass("StructuredDataDict")
-        dimensions = self.universe.extract(("visit", "physical_filter"))
+        dimensions = self.universe.conform(("visit", "physical_filter"))
         dataId = {"instrument": "dummy", "visit": 52, "physical_filter": "V", "band": "v"}
 
         # Create list of refs and list of temporary files
@@ -1824,7 +1829,7 @@ class NullDatastoreTestCase(DatasetTestHelper, unittest.TestCase):
 
     def test_basics(self) -> None:
         storageClass = self.storageClassFactory.getStorageClass("StructuredDataDict")
-        ref = self.makeDatasetRef("metric", DimensionUniverse().extract(()), storageClass, {})
+        ref = self.makeDatasetRef("metric", DimensionUniverse().empty, storageClass, {})
 
         null = NullDatastore(None, None)
 
@@ -1916,25 +1921,22 @@ class StoredFileInfoTestCase(DatasetTestHelper, unittest.TestCase):
 
     def test_StoredFileInfo(self) -> None:
         storageClass = self.storageClassFactory.getStorageClass("StructuredDataDict")
-        ref = self.makeDatasetRef("metric", DimensionUniverse().extract(()), storageClass, {})
+        ref = self.makeDatasetRef("metric", DimensionUniverse().empty, storageClass, {})
 
         record = dict(
             storage_class="StructuredDataDict",
             formatter="lsst.daf.butler.Formatter",
             path="a/b/c.txt",
             component="component",
-            dataset_id=ref.id,
             checksum=None,
             file_size=5,
         )
         info = StoredFileInfo.from_record(record)
 
-        self.assertEqual(info.dataset_id, ref.id)
         self.assertEqual(info.to_record(), record)
 
-        ref2 = self.makeDatasetRef("metric", DimensionUniverse().extract(()), storageClass, {})
+        ref2 = self.makeDatasetRef("metric", DimensionUniverse().empty, storageClass, {})
         rebased = info.rebase(ref2)
-        self.assertEqual(rebased.dataset_id, ref2.id)
         self.assertEqual(rebased.rebase(ref), info)
 
         with self.assertRaises(TypeError):
