@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -29,7 +35,6 @@ from lsst.daf.butler import (
     DataCoordinate,
     DatasetColumnTag,
     DimensionUniverse,
-    TimespanDatabaseRepresentation,
     ddl,
     time_utils,
 )
@@ -37,6 +42,7 @@ from lsst.daf.butler.registry.queries.expressions import make_string_expression_
 from lsst.daf.butler.registry.queries.expressions.check import CheckVisitor, InspectionVisitor
 from lsst.daf.butler.registry.queries.expressions.normalForm import NormalForm, NormalFormExpression
 from lsst.daf.butler.registry.queries.expressions.parser import ParserYacc
+from lsst.daf.butler.timespan_database_representation import TimespanDatabaseRepresentation
 from lsst.daf.relation import ColumnContainer, ColumnExpression
 from sqlalchemy.schema import Column
 
@@ -237,7 +243,7 @@ class InspectionVisitorTestCase(unittest.TestCase):
         tree = parser.parse("instrument = 'LSST'")
         bind = {}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         self.assertFalse(summary.columns)
         self.assertFalse(summary.hasIngestDate)
         self.assertEqual(summary.dataIdKey, universe["instrument"])
@@ -245,23 +251,21 @@ class InspectionVisitorTestCase(unittest.TestCase):
 
         tree = parser.parse("instrument != 'LSST'")
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         self.assertFalse(summary.columns)
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("instrument = 'LSST' AND visit = 1")
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument", "visit", "band", "physical_filter"})
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter"})
         self.assertFalse(summary.columns)
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("instrument = 'LSST' AND visit = 1 AND skymap = 'x'")
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(
-            summary.dimensions.names, {"instrument", "visit", "band", "physical_filter", "skymap"}
-        )
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter", "skymap"})
         self.assertFalse(summary.columns)
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
@@ -274,13 +278,13 @@ class InspectionVisitorTestCase(unittest.TestCase):
         tree = parser.parse("instrument = instr")
         bind = {"instr": "LSST"}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         self.assertFalse(summary.hasIngestDate)
         self.assertEqual(summary.dataIdKey, universe["instrument"])
         self.assertEqual(summary.dataIdValue, "LSST")
 
         tree = parser.parse("instrument != instr")
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         summary = tree.visit(InspectionVisitor(universe, bind))
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
@@ -288,16 +292,14 @@ class InspectionVisitorTestCase(unittest.TestCase):
         tree = parser.parse("instrument = instr AND visit = visit_id")
         bind = {"instr": "LSST", "visit_id": 1}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument", "visit", "band", "physical_filter"})
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("instrument = 'LSST' AND visit = 1 AND skymap = skymap_name")
         bind = {"instr": "LSST", "visit_id": 1, "skymap_name": "x"}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(
-            summary.dimensions.names, {"instrument", "visit", "band", "physical_filter", "skymap"}
-        )
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter", "skymap"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
@@ -309,7 +311,7 @@ class InspectionVisitorTestCase(unittest.TestCase):
         tree = parser.parse("instrument IN ('LSST')")
         bind = {}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         self.assertFalse(summary.hasIngestDate)
         # we do not handle IN with a single item as `=`
         self.assertIsNone(summary.dataIdKey)
@@ -318,28 +320,28 @@ class InspectionVisitorTestCase(unittest.TestCase):
         tree = parser.parse("instrument IN (instr)")
         bind = {"instr": "LSST"}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument"})
+        self.assertEqual(summary.dimensions, {"instrument"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("visit IN (1,2,3)")
         bind = {}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument", "visit", "band", "physical_filter"})
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("visit IN (visit1, visit2, visit3)")
         bind = {"visit1": 1, "visit2": 2, "visit3": 3}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument", "visit", "band", "physical_filter"})
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
         tree = parser.parse("visit IN (visits)")
         bind = {"visits": (1, 2, 3)}
         summary = tree.visit(InspectionVisitor(universe, bind))
-        self.assertEqual(summary.dimensions.names, {"instrument", "visit", "band", "physical_filter"})
+        self.assertEqual(summary.dimensions, {"instrument", "visit", "band", "physical_filter"})
         self.assertIsNone(summary.dataIdKey)
         self.assertIsNone(summary.dataIdValue)
 
@@ -352,28 +354,28 @@ class CheckVisitorTestCase(unittest.TestCase):
         parser = ParserYacc()
 
         universe = DimensionUniverse()
-        graph = universe.extract(("instrument", "visit"))
-        dataId = DataCoordinate.makeEmpty(universe)
-        defaults = DataCoordinate.makeEmpty(universe)
+        dimensions = universe.conform(("instrument", "visit"))
+        dataId = DataCoordinate.make_empty(universe)
+        defaults = DataCoordinate.make_empty(universe)
 
         # governor-only constraint
         tree = parser.parse("instrument = 'LSST'")
         expr = NormalFormExpression.fromTree(tree, NormalForm.DISJUNCTIVE)
         binds = {}
-        visitor = CheckVisitor(dataId, graph, binds, defaults)
+        visitor = CheckVisitor(dataId, dimensions, binds, defaults)
         expr.visit(visitor)
 
         tree = parser.parse("'LSST' = instrument")
         expr = NormalFormExpression.fromTree(tree, NormalForm.DISJUNCTIVE)
         binds = {}
-        visitor = CheckVisitor(dataId, graph, binds, defaults)
+        visitor = CheckVisitor(dataId, dimensions, binds, defaults)
         expr.visit(visitor)
 
         # use bind for governor
         tree = parser.parse("instrument = instr")
         expr = NormalFormExpression.fromTree(tree, NormalForm.DISJUNCTIVE)
         binds = {"instr": "LSST"}
-        visitor = CheckVisitor(dataId, graph, binds, defaults)
+        visitor = CheckVisitor(dataId, dimensions, binds, defaults)
         expr.visit(visitor)
 
 
