@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -30,7 +36,6 @@ from lsst.daf.butler import (
     Config,
     DataCoordinate,
     DatasetType,
-    DimensionGraph,
     DimensionUniverse,
     FileDescriptor,
     Formatter,
@@ -55,7 +60,7 @@ class FormatterFactoryTestCase(unittest.TestCase, DatasetTestHelper):
         self.id = 0
         self.factory = FormatterFactory()
         self.universe = DimensionUniverse()
-        self.dataId = DataCoordinate.makeEmpty(self.universe)
+        self.dataId = DataCoordinate.make_empty(self.universe)
 
         # Dummy FileDescriptor for testing getFormatter
         self.fileDescriptor = FileDescriptor(
@@ -189,7 +194,7 @@ class FormatterFactoryTestCase(unittest.TestCase, DatasetTestHelper):
 
         # Create a DatasetRef with and without instrument matching the
         # one in the config file.
-        dimensions = self.universe.extract(("visit", "physical_filter", "instrument"))
+        dimensions = self.universe.conform(("visit", "physical_filter", "instrument"))
         constant_dataId = {"physical_filter": "v", "visit": 1}
         sc = StorageClass("DummySC", dict, None)
         refPviHsc = self.makeDatasetRef(
@@ -224,7 +229,7 @@ class FormatterFactoryTestCase(unittest.TestCase, DatasetTestHelper):
         self.assertIn("PickleFormatter", refPvixNotHscFmt.name())
 
         # Create a DatasetRef that should fall back to using StorageClass
-        dimensionsNoV = DimensionGraph(self.universe, names=("physical_filter", "instrument"))
+        dimensionsNoV = self.universe.conform(("physical_filter", "instrument"))
         refPvixNotHscDims = self.makeDatasetRef(
             "pvix",
             dimensionsNoV,
