@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -29,7 +35,7 @@ import unittest
 from logging import FileHandler
 
 from lsst.daf.butler import Butler, DatasetRef, DatasetType, FileDataset
-from lsst.daf.butler.core.logging import ButlerLogRecordHandler, JsonLogFormatter
+from lsst.daf.butler.logging import ButlerLogRecordHandler, JsonLogFormatter
 from lsst.daf.butler.tests.utils import makeTestTempDir, removeTestTempDir
 
 TESTDIR = os.path.abspath(os.path.dirname(__file__))
@@ -43,7 +49,7 @@ class ButlerLogRecordsFormatterTestCase(unittest.TestCase):
         Butler.makeRepo(self.root)
 
         self.run = "testrun"
-        self.butler = Butler(self.root, run=self.run)
+        self.butler = Butler.from_config(self.root, run=self.run)
         self.datasetType = DatasetType("test_logs", [], "ButlerLogRecords", universe=self.butler.dimensions)
 
         self.butler.registry.registerDatasetType(self.datasetType)
