@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -115,13 +121,13 @@ class QuantumTestCase(unittest.TestCase):
             dataId43 = dataId43.expanded(records43)  # type: ignore
 
         datasetTypeInit = DatasetType(
-            datasetTypeNameInit, universe.extract(("instrument", "visit")), storageClass
+            datasetTypeNameInit, universe.conform(("instrument", "visit")), storageClass
         )
         datasetTypeInput = DatasetType(
-            datasetTypeNameInput, universe.extract(("instrument", "visit")), storageClass
+            datasetTypeNameInput, universe.conform(("instrument", "visit")), storageClass
         )
         datasetTypeOutput = DatasetType(
-            datasetTypeNameOutput, universe.extract(("instrument", "visit")), storageClass
+            datasetTypeNameOutput, universe.conform(("instrument", "visit")), storageClass
         )
         predictedInputs = {
             datasetTypeInput: [
@@ -172,14 +178,14 @@ class QuantumTestCase(unittest.TestCase):
         self.assertEqual(quantum, quantum.from_simple(serialized, DimensionUniverse()))
 
         # verify direct works
-        jsonVersion = json.loads(serialized.json())
+        jsonVersion = json.loads(serialized.model_dump_json())
         fromDirect = SerializedQuantum.direct(**jsonVersion)
         self.assertEqual(fromDirect, serialized)
 
         # verify direct with records works
         quantum, _ = self._buildFullQuantum(taskName, addRecords=True)
         serialized = quantum.to_simple()
-        jsonVersion = json.loads(serialized.json())
+        jsonVersion = json.loads(serialized.model_dump_json())
         fromDirect = SerializedQuantum.direct(**jsonVersion)
         self.assertEqual(fromDirect, serialized)
 
