@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -37,6 +43,7 @@ from lsst.daf.butler import (
     RegistryConfig,
     StorageClass,
 )
+from lsst.daf.butler.direct_butler import DirectButler
 from lsst.daf.butler.registry import _RegistryFactory
 from lsst.daf.butler.tests.utils import makeTestTempDir, removeTestTempDir
 from lsst.resources import ResourcePath
@@ -56,11 +63,13 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
         # Make a butler and import dimension definitions.
         registryConfig = RegistryConfig(self.config.get("registry"))
         _RegistryFactory(registryConfig).create_from_config(butlerRoot=self.root)
-        self.butler = Butler(self.config, writeable=True, run="RUN")
+        butler = Butler.from_config(self.config, writeable=True, run="RUN")
+        assert isinstance(butler, DirectButler)
+        self.butler = butler
         self.butler.import_(filename=os.path.join(TESTDIR, "data", "registry", "base.yaml"))
 
         # make all dataset types
-        graph = self.universe.extract(("instrument", "detector"))
+        graph = self.universe.conform(("instrument", "detector"))
         storageClass = StorageClass("StructuredDataDict")
         self.datasetTypeInit = DatasetType("test_ds_init", graph, storageClass)
         self.datasetTypeInput = DatasetType("test_ds_input", graph, storageClass)
@@ -177,7 +186,7 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
         self.assertEqual(qbb._actual_output_refs, set())
 
     def test_getput(self) -> None:
-        """Test for getDirect/putDirect methods"""
+        """Test for get/put methods"""
         quantum = self.make_quantum()
         qbb = QuantumBackedButler.initialize(
             config=self.config, quantum=quantum, dimensions=self.universe, dataset_types=self.dataset_types
@@ -210,7 +219,7 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
         self.assertEqual(qbb._actual_output_refs, set(self.output_refs))
 
     def test_getDeferred(self) -> None:
-        """Test for getDirectDeferred method"""
+        """Test for getDeferred method"""
         quantum = self.make_quantum()
         qbb = QuantumBackedButler.initialize(
             config=self.config, quantum=quantum, dimensions=self.universe, dataset_types=self.dataset_types
@@ -234,7 +243,7 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
         self.assertEqual(qbb._actual_inputs, {ref.id for ref in input_refs + self.init_inputs_refs})
         self.assertEqual(qbb._unavailable_inputs, {ref.id for ref in self.missing_refs})
 
-    def test_datasetExistsDirect(self) -> None:
+    def test_stored(self) -> None:
         """Test for dataset existence method"""
         quantum = self.make_quantum()
         qbb = QuantumBackedButler.initialize(
@@ -266,7 +275,7 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
         # _available_inputs is not
         self.assertEqual(qbb._available_inputs, {ref.id for ref in input_refs + self.init_inputs_refs})
         self.assertEqual(qbb._actual_inputs, set())
-        self.assertEqual(qbb._unavailable_inputs, set())  # this is not consistent with getDirect?
+        self.assertEqual(qbb._unavailable_inputs, set())  # this is not consistent with get?
 
     def test_markInputUnused(self) -> None:
         """Test for markInputUnused method"""
@@ -349,7 +358,7 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
             qbb.put({"data": cast(int, ref.dataId["detector"]) ** 2}, ref)
 
         provenance1 = qbb.extract_provenance_data()
-        prov_json = provenance1.json()
+        prov_json = provenance1.model_dump_json()
         provenance2 = QuantumProvenanceData.direct(**json.loads(prov_json))
         for provenance in (provenance1, provenance2):
             input_ids = {ref.id for ref in self.input_refs + self.init_inputs_refs}
@@ -363,14 +372,12 @@ class QuantumBackedButlerTestCase(unittest.TestCase):
             self.assertEqual(set(provenance.datastore_records.keys()), {datastore_name})
             datastore_records = provenance.datastore_records[datastore_name]
             self.assertEqual(set(datastore_records.dataset_ids), output_ids)
-            class_name = "lsst.daf.butler.core.storedFileInfo.StoredFileInfo"
-            table_name = "file_datastore_records"
+            class_name = "lsst.daf.butler.datastore.stored_file_info.StoredFileInfo"
             self.assertEqual(set(datastore_records.records.keys()), {class_name})
-            self.assertEqual(set(datastore_records.records[class_name].keys()), {table_name})
-            self.assertEqual(
-                {record["dataset_id"] for record in datastore_records.records[class_name][table_name]},
-                output_ids,
-            )
+            self.assertEqual(set(datastore_records.records[class_name].keys()), {id.hex for id in output_ids})
+            table_name = "file_datastore_records"
+            for dataset_data in datastore_records.records[class_name].values():
+                self.assertEqual(set(dataset_data), {table_name})
 
     def test_collect_and_transfer(self) -> None:
         """Test for collect_and_transfer method"""
