@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -25,7 +31,12 @@ import os.path
 import re
 import unittest
 
-from lsst.daf.butler.registry import MissingSpatialOverlapError, RegistryConfig, _RegistryFactory, queries
+from lsst.daf.butler import (
+    DataCoordinateQueryResults,
+    DimensionRecordQueryResults,
+    SingleTypeDatasetQueryResults,
+)
+from lsst.daf.butler.registry import MissingSpatialOverlapError, RegistryConfig, _RegistryFactory
 from lsst.daf.butler.transfers import YamlRepoImportBackend
 
 TESTDIR = os.path.abspath(os.path.dirname(__file__))
@@ -91,9 +102,7 @@ class TestQueryRelationsTests(unittest.TestCase):
     def assert_relation_str(
         self,
         expected: str,
-        *results: queries.DataCoordinateQueryResults
-        | queries.DimensionRecordQueryResults
-        | queries.ParentDatasetQueryResults,
+        *results: DataCoordinateQueryResults | DimensionRecordQueryResults | SingleTypeDatasetQueryResults,
     ) -> None:
         """Assert that checks that one or more registry
         queries have relation trees that match the given string.
@@ -142,11 +151,11 @@ class TestQueryRelationsTests(unittest.TestCase):
                         select(
                             Π[band, patch, patch.region, skymap, tract, visit_detector_region.region](
                                 σ[
-                                    band={self.band!r}
-                                    and instrument={self.instrument!r}
+                                    instrument={self.instrument!r}
                                     and detector={self.detector!r}
-                                    and physical_filter={self.physical_filter!r}
                                     and visit={self.visit!r}
+                                    and band={self.band!r}
+                                    and physical_filter={self.physical_filter!r}
                                 ](
                                     patch_htm7_overlap
                                     ⋈ visit_detector_region_htm7_overlap
@@ -167,11 +176,11 @@ class TestQueryRelationsTests(unittest.TestCase):
             self.registry.queryDataIds(
                 ["patch", "band"],
                 where=(
-                    f"band={self.band!r} "
-                    f"and instrument={self.instrument!r} "
+                    f"instrument={self.instrument!r} "
                     f"and detector={self.detector!r} "
-                    f"and physical_filter={self.physical_filter!r} "
                     f"and visit={self.visit!r}"
+                    f"and band={self.band!r} "
+                    f"and physical_filter={self.physical_filter!r} "
                 ),
             ),
         )
@@ -188,11 +197,11 @@ class TestQueryRelationsTests(unittest.TestCase):
             select(
                 Π[htm7](
                     σ[
-                        band={self.band!r}
-                        and instrument={self.instrument!r}
+                        instrument={self.instrument!r}
                         and detector={self.detector!r}
-                        and physical_filter={self.physical_filter!r}
                         and visit={self.visit!r}
+                        and band={self.band!r}
+                        and physical_filter={self.physical_filter!r}
                     ](
                         visit_detector_region_htm7_overlap
                         ⋈ physical_filter
@@ -211,11 +220,11 @@ class TestQueryRelationsTests(unittest.TestCase):
             self.registry.queryDataIds(
                 ["htm7"],
                 where=(
-                    f"band={self.band!r} "
-                    f"and instrument={self.instrument!r} "
+                    f"instrument={self.instrument!r} "
                     f"and detector={self.detector!r} "
-                    f"and physical_filter={self.physical_filter!r} "
                     f"and visit={self.visit!r}"
+                    f"and band={self.band!r} "
+                    f"and physical_filter={self.physical_filter!r} "
                 ),
             ),
         )
@@ -293,10 +302,10 @@ class TestQueryRelationsTests(unittest.TestCase):
                         select(
                             Π[detector, instrument, visit_detector_region.region](
                                 σ[
-                                    band={self.band!r}
-                                    and instrument={self.instrument!r}
-                                    and physical_filter={self.physical_filter!r}
+                                    instrument={self.instrument!r}
                                     and visit={self.visit!r}
+                                    and band={self.band!r}
+                                    and physical_filter={self.physical_filter!r}
                                     and htm7={self.htm7!r}
                                 ](
                                     visit_detector_region_htm7_overlap
@@ -324,11 +333,11 @@ class TestQueryRelationsTests(unittest.TestCase):
             select(
                 Π[detector, instrument](
                     σ[
-                        band={self.band!r}
-                        and htm7={self.htm7!r}
+                        htm7={self.htm7!r}
                         and instrument={self.instrument!r}
-                        and physical_filter={self.physical_filter!r}
                         and visit={self.visit!r}
+                        and band={self.band!r}
+                        and physical_filter={self.physical_filter!r}
                     ](
                         visit_detector_region_htm7_overlap
                         ⋈ physical_filter
