@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -51,7 +57,7 @@ class SimpleButlerTestCase(unittest.TestCase):
     datasetsManager = (
         "lsst.daf.butler.registry.datasets.byDimensions.ByDimensionsDatasetRecordStorageManagerUUID"
     )
-    datasetsImportFile = "datasets-uuid.yaml"
+    datasetsImportFile = "datasets.yaml"
 
     def setUp(self):
         self.root = makeTestTempDir(TESTDIR)
@@ -73,7 +79,7 @@ class SimpleButlerTestCase(unittest.TestCase):
         registryConfig = RegistryConfig(config.get("registry"))
         _RegistryFactory(registryConfig).create_from_config()
 
-        butler = Butler(config, **kwargs)
+        butler = Butler.from_config(config, **kwargs)
         DatastoreMock.apply(butler)
         return butler
 
@@ -271,8 +277,8 @@ class SimpleButlerTestCase(unittest.TestCase):
 
         # Find the DatasetRef for a flat
         coll = "imported_g"
-        flat2g = butler.registry.findDataset(
-            "flat", instrument="Cam1", detector=2, physical_filter="Cam1-G", collections=coll
+        flat2g = butler.find_dataset(
+            "flat", instrument="Cam1", full_name="Ab", physical_filter="Cam1-G", collections=coll
         )
 
         # Create a numpy integer to check that works fine
@@ -318,7 +324,8 @@ class SimpleButlerTestCase(unittest.TestCase):
             try:
                 flat_id, _ = butler.get("flat", dataId=dataId, collections=coll, **kwds)
             except Exception as e:
-                raise type(e)(f"{str(e)}: dataId={dataId}, kwds={kwds}") from e
+                e.add_note(f"dataId={dataId}, kwds={kwds}")
+                raise
             self.assertEqual(flat_id, flat2g.id, msg=f"DataId: {dataId}, kwds: {kwds}")
 
         # Check that bad combinations raise.
@@ -506,7 +513,7 @@ class SimpleButlerTestCase(unittest.TestCase):
         # input collections.
         butler.registry.defaults = RegistryDefaults(collections=["imported_g"])
         # Use findDataset without collections or instrument.
-        ref = butler.registry.findDataset("flat", detector=2, physical_filter="Cam1-G")
+        ref = butler.find_dataset("flat", detector=2, physical_filter="Cam1-G")
         # Do the same with Butler.get; this should ultimately invoke a lot of
         # the same code, so it's a bit circular, but mostly we're checking that
         # it works at all.
@@ -543,16 +550,16 @@ class SimpleButlerTestCase(unittest.TestCase):
         # Initialize a new butler with `imported_g` as its default run.
         # This should not have a default instrument, because there are two.
         # Pass run instead of collections; this should set both.
-        butler2 = Butler(butler=butler, run="imported_g")
+        butler2 = Butler.from_config(butler=butler, run="imported_g")
         self.assertEqual(list(butler2.registry.defaults.collections), ["imported_g"])
         self.assertEqual(butler2.registry.defaults.run, "imported_g")
         self.assertFalse(butler2.registry.defaults.dataId)
         # Initialize a new butler with an instrument default explicitly given.
         # Set collections instead of run, which should then be None.
-        butler3 = Butler(butler=butler, collections=["imported_g"], instrument="Cam2")
+        butler3 = Butler.from_config(butler=butler, collections=["imported_g"], instrument="Cam2")
         self.assertEqual(list(butler3.registry.defaults.collections), ["imported_g"])
         self.assertIsNone(butler3.registry.defaults.run, None)
-        self.assertEqual(butler3.registry.defaults.dataId.byName(), {"instrument": "Cam2"})
+        self.assertEqual(butler3.registry.defaults.dataId.required, {"instrument": "Cam2"})
 
         # Check that repr() does not fail.
         defaults = RegistryDefaults(collections=["imported_g"], run="test")
@@ -577,7 +584,7 @@ class SimpleButlerTestCase(unittest.TestCase):
         # input collections.
         butler.registry.defaults = RegistryDefaults(collections=["imported_g"])
         # Use findDataset without collections or instrument.
-        ref = butler.registry.findDataset("flat", detector=2, physical_filter="Cam1-G")
+        ref = butler.find_dataset("flat", detector=2, physical_filter="Cam1-G")
 
         # Transform the ref and dataset type to and from JSON
         # and check that it can be reconstructed properly
@@ -596,6 +603,23 @@ class SimpleButlerTestCase(unittest.TestCase):
                     from_json = type(test_item).from_json(json_str, universe=butler.dimensions)
                     self.assertEqual(from_json, test_item, msg=f"From JSON '{json_str}' using universe")
 
+    def test_populated_by(self):
+        """Test that dimension records can find other records."""
+        butler = self.makeButler(writeable=True)
+        butler.import_(filename=os.path.join(TESTDIR, "data", "registry", "hsc-rc2-subset.yaml"))
+
+        elements = frozenset(element for element in butler.dimensions.elements if element.has_own_table)
+
+        # Get a visit-based dataId.
+        data_ids = set(butler.registry.queryDataIds("visit", visit=1232, instrument="HSC"))
+
+        # Request all the records related to it.
+        records = butler._extract_all_dimension_records_from_data_ids(butler, data_ids, elements)
+
+        self.assertIn(butler.dimensions["visit_detector_region"], records, f"Keys: {records.keys()}")
+        self.assertIn(butler.dimensions["visit_system_membership"], records)
+        self.assertIn(butler.dimensions["visit_system"], records)
+
     def testJsonDimensionRecordsAndHtmlRepresentation(self):
         # Dimension Records
         butler = self.makeButler(writeable=True)
@@ -651,13 +675,5 @@ class SimpleButlerTestCase(unittest.TestCase):
             self.assertEqual(set(result), expected)
 
 
-class SimpleButlerMixedUUIDTestCase(SimpleButlerTestCase):
-    """Same as SimpleButlerTestCase but uses UUID-based datasets manager and
-    loads datasets from YAML file with integer IDs.
-    """
-
-    datasetsImportFile = "datasets.yaml"
-
-
 if __name__ == "__main__":
     unittest.main()
