@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -95,7 +101,7 @@ class StorageClassFactoryTestCase(unittest.TestCase):
         self.assertIn("comp1", scc.components)
         r = repr(scc)
         self.assertIn("comp1", r)
-        self.assertIn("lsst.daf.butler.core.storageClassDelegate.StorageClassDelegate", r)
+        self.assertIn("lsst.daf.butler.StorageClassDelegate", r)
 
         # Ensure that we have a delegate
         self.assertIsInstance(scc.delegate(), StorageClassDelegate)
@@ -112,9 +118,9 @@ class StorageClassFactoryTestCase(unittest.TestCase):
 
         # Check we can create a storageClass using the name of an importable
         # type.
-        sc2 = StorageClass("TestImage2", "lsst.daf.butler.core.storageClass.StorageClassFactory")
+        sc2 = StorageClass("TestImage2", "lsst.daf.butler.StorageClassFactory")
         self.assertIsInstance(sc2.pytype(), StorageClassFactory)
-        self.assertIn("butler.core", repr(sc2))
+        self.assertIn("butler", repr(sc2))
 
     def testParameters(self):
         """Test that we can set parameters and validate them"""
@@ -178,7 +184,7 @@ class StorageClassFactoryTestCase(unittest.TestCase):
         self.assertTrue(sc1.is_type(dict), repr(sc1))
         self.assertFalse(sc1.is_type(str), repr(sc1))
 
-        sc2 = StorageClass("TestImage2", "lsst.daf.butler.core.storageClass.StorageClassFactory")
+        sc2 = StorageClass("TestImage2", "lsst.daf.butler.StorageClassFactory")
         self.assertTrue(sc2.is_type(StorageClassFactory), repr(sc2))
 
     def testRegistry(self):
@@ -237,6 +243,12 @@ class StorageClassFactoryTestCase(unittest.TestCase):
         # Check you can silently insert something that is already there
         factory.registerStorageClass(newclass3)
 
+        # Reset the factory and check that default items are present
+        # but the new ones are not.
+        factory.reset()
+        self.assertNotIn(newclass3.name, factory)
+        self.assertIn("StructuredDataDict", factory)
+
     def testFactoryFind(self):
         # Finding a storage class can involve doing lots of slow imports so
         # this is a separate test.
@@ -325,7 +337,7 @@ class StorageClassFactoryTestCase(unittest.TestCase):
             # Add some entries that will fail to import.
             "lsst.daf.butler.bad.type": "lsst.daf.butler.tests.MetricsExampleModel.from_metrics",
             "lsst.daf.butler.tests.MetricsExampleModel": "lsst.daf.butler.bad.function",
-            "lsst.daf.butler.Butler": "lsst.daf.butler.core.location.__all__",
+            "lsst.daf.butler.Butler": "lsst.daf.butler.location.__all__",
             "list": get_full_type_name(self._convert_type),
         }
         sc = StorageClass(className, pytype=dict, converters=converters)
