@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -30,13 +36,14 @@ from lsst.daf.butler import (
     DatasetId,
     DatasetRef,
     DatasetType,
-    DimensionGraph,
     DimensionUniverse,
+    StorageClass,
+)
+from lsst.daf.butler.datastore.file_templates import (
     FileTemplate,
     FileTemplates,
     FileTemplatesConfig,
     FileTemplateValidationError,
-    StorageClass,
 )
 
 TESTDIR = os.path.abspath(os.path.dirname(__file__))
@@ -57,8 +64,8 @@ class TestFileTemplates(unittest.TestCase):
             dataId = self.dataId
         if "physical_filter" in dataId and "band" not in dataId:
             dataId["band"] = "b"  # Add fake band.
-        dimensions = DimensionGraph(self.universe, names=dataId.keys())
-        dataId = DataCoordinate.standardize(dataId, graph=dimensions)
+        dimensions = self.universe.conform(dataId.keys())
+        dataId = DataCoordinate.standardize(dataId, dimensions=dimensions)
 
         # Pretend we have a parent if this looks like a composite
         compositeName, componentName = DatasetType.splitDatasetTypeName(datasetTypeName)
