@@ -6,6 +6,12 @@
 # See the COPYRIGHT file at the top-level directory of this distribution
 # for details of code ownership.
 #
+# This software is dual licensed under the GNU General Public License and also
+# under a 3-clause BSD license. Recipients may choose which of these licenses
+# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
+# respectively.  If you choose the GPL option then the following text applies
+# (but note that there is still no warranty even if you opt for BSD instead):
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -112,7 +118,7 @@ class ButlerUtilsTestSuite(unittest.TestCase):
     def _checkButlerDimension(self, dimensions, query, expected):
         result = list(self.butler.registry.queryDataIds(dimensions, where=query, check=False))
         self.assertEqual(len(result), 1)
-        self.assertIn(result[0].byName(), expected)
+        self.assertIn(result[0].required, expected)
 
     def testButlerDimensions(self):
         self._checkButlerDimension(
@@ -165,13 +171,14 @@ class ButlerUtilsTestSuite(unittest.TestCase):
     def testAddDatasetType(self):
         # 1 for StructuredDataNoComponents, 1 for StructuredData (components
         # not included).
-        self.assertEqual(len(list(self.butler.registry.queryDatasetTypes(components=False))), 2)
+        with self.assertWarns(FutureWarning):
+            self.assertEqual(len(list(self.butler.registry.queryDatasetTypes(components=False))), 2)
 
         # Testing the DatasetType objects is not practical, because all tests
         # need a DimensionUniverse. So just check that we have the dataset
         # types we expect.
-        self.butler.registry.getDatasetType("DataType1")
-        self.butler.registry.getDatasetType("DataType2")
+        self.butler.get_dataset_type("DataType1")
+        self.butler.get_dataset_type("DataType2")
 
         with self.assertRaises(ValueError):
             addDatasetType(self.butler, "DataType3", {"4thDimension"}, "NumpyArray")
@@ -205,7 +212,7 @@ class ButlerUtilsTestSuite(unittest.TestCase):
             ]
 
             repo = lsst.daf.butler.Butler.makeRepo(temp, config=config)
-            butler = lsst.daf.butler.Butler(repo, run="chainedExample")
+            butler = lsst.daf.butler.Butler.from_config(repo, run="chainedExample")
             registerMetricsExample(butler)
             addDatasetType(butler, "DummyType", {}, "StructuredDataNoComponents")
 
@@ -231,18 +238,18 @@ class ButlerUtilsTestSuite(unittest.TestCase):
 
     def testExpandUniqueId(self):
         self.assertEqual(
-            dict(expandUniqueId(self.butler, {"instrument": "notACam"})), {"instrument": "notACam"}
+            expandUniqueId(self.butler, {"instrument": "notACam"}).required, {"instrument": "notACam"}
         )
         self.assertIn(
-            dict(expandUniqueId(self.butler, {"visit": 101})),
+            expandUniqueId(self.butler, {"visit": 101}).required,
             [{"instrument": "notACam", "visit": 101}, {"instrument": "dummyCam", "visit": 101}],
         )
         self.assertIn(
-            dict(expandUniqueId(self.butler, {"detector": 5})),
+            expandUniqueId(self.butler, {"detector": 5}).required,
             [{"instrument": "notACam", "detector": 5}, {"instrument": "dummyCam", "detector": 5}],
         )
         self.assertIn(
-            dict(expandUniqueId(self.butler, {"physical_filter": "k2020"})),
+            expandUniqueId(self.butler, {"physical_filter": "k2020"}).required,
             [
                 {"instrument": "notACam", "physical_filter": "k2020"},
                 {"instrument": "notACam", "physical_filter": "k2020"},
